from .config import Config, ctypes
from .config import auto_encode

#HDHOOK send HOOK回调
#typedef __int32(__stdcall *HandleCallBackFunType_Send)(__int32 窗口序号, __int32 插件序号, __int64 rcxOrl1, __int64 rdxOrl2, __int64 r8Orl3, __int64 r9Orl4, __int64 rbp, __int64 rsp, __int64 rip, char*buffer, __int32 bufferMaxSize, __int32 bufferRealSize, __int64 lparam);//返回1表示要修改
HD_HandleCallBackFunTypeSend_stdcall = ctypes.WINFUNCTYPE(ctypes.c_int32,ctypes.c_int32,ctypes.c_int32,ctypes.c_int64,ctypes.c_int64,ctypes.c_int64,ctypes.c_int64,ctypes.c_int64,ctypes.c_int64,ctypes.c_int64,ctypes.c_char_p,ctypes.c_int32,ctypes.c_int32,ctypes.c_int64)

#HDHOOK sendto HOOK回调
#typedef __int32(__stdcall *HandleCallBackFunType_SendTo)(__int32 窗口序号, __int32 插件序号, __int64 rcxOrl1, __int64 rdxOrl2, __int64 r8Orl3, __int64 r9Orl4,  __int64 l5, __int64 l6, __int64 rbp, __int64 rsp, __int64 rip, char*buffer, __int32 bufferMaxSize, __int32 bufferRealSize, __int64 lparam);//返回1表示要修改
HD_HandleCallBackFunTypeSendTo_stdcall = ctypes.WINFUNCTYPE(ctypes.c_int32,ctypes.c_int32,ctypes.c_int32,ctypes.c_int64,ctypes.c_int64,ctypes.c_int64,ctypes.c_int64,ctypes.c_int64,ctypes.c_int64,ctypes.c_int64,ctypes.c_int64,ctypes.c_int64,ctypes.c_char_p,ctypes.c_int32,ctypes.c_int32,ctypes.c_int64)

#HDHOOK recv HOOK回调
#typedef __int32(__stdcall *HandleCallBackFunType_Recv)(__int32 窗口序号, __int32 插件序号, __int64 rcxOrl1, __int64 rdxOrl2, __int64 r8Orl3, __int64 r9Orl4, __int64 rbp, __int64 rsp, __int64 rip, char*buffer, __int32 bufferMaxSize, __int32 bufferRealSize, __int64 lparam);//返回1表示要修改
HD_HandleCallBackFunTypeRecv_stdcall = ctypes.WINFUNCTYPE(ctypes.c_int32,ctypes.c_int32,ctypes.c_int32,ctypes.c_int64,ctypes.c_int64,ctypes.c_int64,ctypes.c_int64,ctypes.c_int64,ctypes.c_int64,ctypes.c_int64,ctypes.c_char_p,ctypes.c_int32,ctypes.c_int32,ctypes.c_int64)

#HDHOOK recvFrom HOOK回调
#typedef __int32(__stdcall *HandleCallBackFunType_RecvFrom)(__int32 窗口序号, __int32 插件序号, __int64 rcxOrl1, __int64 rdxOrl2, __int64 r8Orl3, __int64 r9Orl4,  __int64 l5, __int64 l6, __int64 rbp, __int64 rsp, __int64 rip, char*buffer, __int32 bufferMaxSize, __int32 bufferRealSize, __int64 lparam);//返回1表示要修改
HD_HandleCallBackFunTypeRecvFrom_stdcall = ctypes.WINFUNCTYPE(ctypes.c_int32,ctypes.c_int32,ctypes.c_int32,ctypes.c_int64,ctypes.c_int64,ctypes.c_int64,ctypes.c_int64,ctypes.c_int64,ctypes.c_int64,ctypes.c_int64,ctypes.c_int64,ctypes.c_int64,ctypes.c_char_p,ctypes.c_int32,ctypes.c_int32,ctypes.c_int64)


#HDHOOK 任意点HOOK回调
#typedef __int64(__stdcall *HandleCallBackFunType)(__int32 窗口序号, __int32 插件序号,__int64 raxOreax, __int64 rbxOrebx,__int64 rcxOrecx, __int64 rdxOredx,__int64 rbpOrebp, __int64 rspOresp,__int64 rsiOresi, __int64 rdiOredi,__int64 r8, __int64 r9, __int64 r10, __int64 r11, __int64 r12, __int64 r13, __int64 r14, __int64 r15,__int64 lparam);
HD_HandleCallBackFunTypeHook_stdcall = ctypes.WINFUNCTYPE(ctypes.c_int64,ctypes.c_int32,ctypes.c_int32,ctypes.c_int64,ctypes.c_int64,ctypes.c_int64,ctypes.c_int64,ctypes.c_int64,ctypes.c_int64,ctypes.c_int64,ctypes.c_int64,ctypes.c_int64,ctypes.c_int64,ctypes.c_int64,ctypes.c_int64,ctypes.c_int64,ctypes.c_int64,ctypes.c_int64,ctypes.c_int64,ctypes.c_int64)


# INT64 __stdcall HDHK_InterceptApi(int 窗口序号, char* 模块名字, char* 拦截接口名字, int 破坏字节数, INT64 回调地址, INT64 附加参数, BOOL 是否主线程调用);
def HDHOOK_拦截API(窗口序号: int, 模块名字: str, 拦截接口名字: str, 破坏字节数: int, 回调地址: HD_HandleCallBackFunTypeSend_stdcall, 附加参数: int, 是否主线程调用: bool = False) -> int:
    """
    设置拦截API(内置插件)X86X64
    :param 窗口序号: 窗口序号 (从1开始)
    :param 模块名字: 接口所在的dll模块名字
    :param 拦截接口名字: 接口名字 如:send sendto recv recvfrom 注意是小写字母！
    :param 破坏字节数: [ X86->send recv sendto recvfrom是5 ] [ X64->send recv是5 sendto recvfrom是7]
    :param 回调地址: 遵循下面回调函数类型
    :param 附加参数: 自定义参数,此参数会传递给回调函数
    :param 是否主线程调用: 需要开启才开启,一般默认就行 (默认False)
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    HDHK_InterceptApi = hd.HDHK_InterceptApi
    HDHK_InterceptApi.restype = ctypes.c_int64

    # 使用auto_encode自动转换编码
    module_bytes = auto_encode(模块名字)
    interface_bytes = auto_encode(拦截接口名字)
    #判断 走不同的回调
    if 拦截接口名字 == "send" or 拦截接口名字 == "recv":
        HDHK_InterceptApi.argtypes = [
            ctypes.c_int32,  # 窗口序号
            ctypes.c_char_p,  # 模块名字
            ctypes.c_char_p,  # 拦截接口名字
            ctypes.c_int32,  # 破坏字节数
            ctypes.c_int64,  # 回调地址 send recv一样
            ctypes.c_int64,  # 附加参数
            ctypes.c_bool  # 是否主线程调用
        ]
        #
        回调地址Fun = HD_HandleCallBackFunTypeSend_stdcall(回调地址)
        # 正确获取回调函数的地址并转换为64位整数：使用ctypes.cast将回调对象转换为c_void_p，然后获取其数值并转为c_int64。
        回调地址Fun_ptr = ctypes.c_int64(ctypes.cast(回调地址Fun, ctypes.c_void_p).value) if 回调地址Fun else ctypes.c_int64(0)

        # 调用C函数
        return HDHK_InterceptApi(
            ctypes.c_int32(窗口序号),
            module_bytes,
            interface_bytes,
            ctypes.c_int32(破坏字节数),
            回调地址Fun_ptr,
            ctypes.c_int64(附加参数),
            ctypes.c_bool(是否主线程调用)
        )
    elif 拦截接口名字 == "sendto" or 拦截接口名字 == "recvfrom":
        HDHK_InterceptApi.argtypes = [
            ctypes.c_int32,  # 窗口序号
            ctypes.c_char_p,  # 模块名字
            ctypes.c_char_p,  # 拦截接口名字
            ctypes.c_int32,  # 破坏字节数
            ctypes.c_int64,  # 回调地址 send recv一样
            ctypes.c_int64,  # 附加参数
            ctypes.c_bool  # 是否主线程调用
        ]
        #
        回调地址Fun = HD_HandleCallBackFunTypeSendTo_stdcall(回调地址)
        # 正确获取回调函数的地址并转换为64位整数：使用ctypes.cast将回调对象转换为c_void_p，然后获取其数值并转为c_int64。
        回调地址Fun_ptr = ctypes.c_int64(ctypes.cast(回调地址Fun, ctypes.c_void_p).value) if 回调地址Fun else ctypes.c_int64(0)
        # 调用C函数
        return HDHK_InterceptApi(
          ctypes.c_int32(窗口序号),
          module_bytes,
          interface_bytes,
          ctypes.c_int32(破坏字节数),
            回调地址Fun_ptr,
          ctypes.c_int64(附加参数),
          ctypes.c_bool(是否主线程调用)
        )
    else:
        return 0

# INT64 __stdcall HDHK_PauseInterceptApi(int 窗口序号, char* 模块名字, char* 拦截接口名字, BOOL 是否主线程调用);
def HDHOOK_暂停拦截API(窗口序号: int, 模块名字: str, 拦截接口名字: str, 是否主线程调用: bool = False) -> int:
    """
    暂停拦截API(内置插件)X86X64
    :param 窗口序号: 窗口序号 (从1开始)
    :param 模块名字: 接口所在的dll模块名字
    :param 拦截接口名字: 接口名字 如:send sendto recv recvfrom 注意是小写字母！
    :param 是否主线程调用: 需要开启才开启,一般默认就行 (默认False)
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    HDHK_PauseInterceptApi = hd.HDHK_PauseInterceptApi
    HDHK_PauseInterceptApi.restype = ctypes.c_int64
    HDHK_PauseInterceptApi.argtypes = [ctypes.c_int32, ctypes.c_char_p, ctypes.c_char_p, ctypes.c_bool]

    # 使用auto_encode自动转换编码
    module_bytes = auto_encode(模块名字)
    interface_bytes = auto_encode(拦截接口名字)

    ret = HDHK_PauseInterceptApi(
        ctypes.c_int32(窗口序号),
        module_bytes,
        interface_bytes,
        ctypes.c_bool(是否主线程调用)
    )

    return ret

# INT64 __stdcall HDHK_RecoverInterceptApi(int 窗口序号, char* 模块名字, char* 拦截接口名字, BOOL 是否主线程调用);
def HDHOOK_恢复拦截API(窗口序号: int, 模块名字: str, 拦截接口名字: str, 是否主线程调用: bool = False) -> int:
    """
    恢复拦截API(内置插件)X86X64
    :param 窗口序号: 窗口序号 (从1开始)
    :param 模块名字: 接口所在的dll模块名字
    :param 拦截接口名字: 接口名字 如:send sendto recv recvfrom 注意是小写字母！
    :param 是否主线程调用: 需要开启才开启,一般默认就行 (默认False)
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    HDHK_RecoverInterceptApi = hd.HDHK_RecoverInterceptApi
    HDHK_RecoverInterceptApi.restype = ctypes.c_int64
    HDHK_RecoverInterceptApi.argtypes = [ctypes.c_int32, ctypes.c_char_p, ctypes.c_char_p, ctypes.c_bool]

    # 使用auto_encode自动转换编码
    module_bytes = auto_encode(模块名字)
    interface_bytes = auto_encode(拦截接口名字)

    ret = HDHK_RecoverInterceptApi(
        ctypes.c_int32(窗口序号),
        module_bytes,
        interface_bytes,
        ctypes.c_bool(是否主线程调用)
    )

    return ret

# INT64 __stdcall HDHK_UnInterceptApi(int 窗口序号, char* 模块名字, char* 拦截接口名字, BOOL 是否主线程调用);
def HDHOOK_卸载拦截API(窗口序号: int, 模块名字: str, 拦截接口名字: str, 是否主线程调用: bool = False) -> int:
    """
    卸载拦截API(内置插件)X86X64
    :param 窗口序号: 窗口序号 (从1开始)
    :param 模块名字: 接口所在的dll模块名字
    :param 拦截接口名字: 接口名字 如:send sendto recv recvfrom 注意是小写字母！
    :param 是否主线程调用: 需要开启才开启,一般默认就行 (默认False)
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    HDHK_UnInterceptApi = hd.HDHK_UnInterceptApi
    HDHK_UnInterceptApi.restype = ctypes.c_int64
    HDHK_UnInterceptApi.argtypes = [ctypes.c_int32, ctypes.c_char_p, ctypes.c_char_p, ctypes.c_bool]

    # 使用auto_encode自动转换编码
    module_bytes = auto_encode(模块名字)
    interface_bytes = auto_encode(拦截接口名字)

    ret = HDHK_UnInterceptApi(
        ctypes.c_int32(窗口序号),
        module_bytes,
        interface_bytes,
        ctypes.c_bool(是否主线程调用)
    )

    return ret

#INT64 HDHK_SendApi(int 窗口序号, int socket, BYTE *buffer, int bufferSize, int flag, BOOL 是否主线程调用 = FALSE);
# INT64 __stdcall HDHK_SendApi(int 窗口序号, int socket, BYTE *buffer, int bufferSize, int flag, BOOL 是否主线程调用);
def HDHOOK_Send发包(窗口序号: int, socket: int, buffer: bytes, bufferSize: int, flag: int, 是否主线程调用: bool = False) -> int:
    """
    发送API(内置插件)X86X64
    :param 窗口序号: 窗口序号 (从1开始)
    :param socket: 套接字
    :param buffer: 数据缓冲区 (bytes) - 字节数组，如：b'\x01\x02\x03' 或 bytes([1, 2, 3])
    :param bufferSize: 缓冲区大小
    :param flag: 标志
    :param 是否主线程调用: 需要开启才开启,一般默认就行 (默认False)
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    HDHK_SendApi = hd.HDHK_SendApi
    HDHK_SendApi.restype = ctypes.c_int64
    HDHK_SendApi.argtypes = [
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.POINTER(ctypes.c_ubyte),
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_bool
    ]

    buffer_array = (ctypes.c_ubyte * bufferSize)(*buffer)

    ret = HDHK_SendApi(
        ctypes.c_int32(窗口序号),
        ctypes.c_int32(socket),
        buffer_array,
        ctypes.c_int32(bufferSize),
        ctypes.c_int32(flag),
        ctypes.c_bool(是否主线程调用)
    )

    return ret

# INT64 __stdcall HDHK_SendToApi(int 窗口序号, int socket, BYTE *buffer, int bufferSize, int flag, int port, int ip, BOOL 是否主线程调用);
def HDHOOK_SendTo发包(窗口序号: int, socket: int, buffer: bytes, bufferSize: int, flag: int, port: int, ip: int, 是否主线程调用: bool = False) -> int:
    """
    发送到API(内置插件)X86X64
    :param 窗口序号: 窗口序号 (从1开始)
    :param socket: 套接字
    :param buffer: 数据缓冲区 (bytes) - 字节数组，如：b'\x01\x02\x03' 或 bytes([1, 2, 3])
    :param bufferSize: 缓冲区大小
    :param flag: 标志
    :param port: 目标端口
    :param ip: 目标IP地址
    :param 是否主线程调用: 需要开启才开启,一般默认就行 (默认False)
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    HDHK_SendToApi = hd.HDHK_SendToApi
    HDHK_SendToApi.restype = ctypes.c_int64
    HDHK_SendToApi.argtypes = [
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.POINTER(ctypes.c_ubyte),
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_bool
    ]

    buffer_array = (ctypes.c_ubyte * bufferSize)(*buffer)

    ret = HDHK_SendToApi(
        ctypes.c_int32(窗口序号),
        ctypes.c_int32(socket),
        buffer_array,
        ctypes.c_int32(bufferSize),
        ctypes.c_int32(flag),
        ctypes.c_int32(port),
        ctypes.c_int32(ip),
        ctypes.c_bool(是否主线程调用)
    )

    return ret

# INT64 __stdcall HDHK_SetProcessCallBackLparamSendX86(int 窗口序号, int l1, int l2, int l3, int l4, int ebp, int esp, int eip, int mark);
def HDHOOK_设置拦截Send返回参数X86(窗口序号: int, l1: int = None, l2: int = None, l3: int = None, l4: int = None, ebp: int = None, esp: int = None, eip: int = None, mark: int = 0) -> int:
    """
    设置回调函数返回值给目标进程（Send API）
    :param 窗口序号: 窗口序号 (从1开始)
    :param l1: 参数1
    :param l2: 参数2
    :param l3: 参数3
    :param l4: 参数4
    :param ebp: EBP寄存器值
    :param esp: ESP寄存器值
    :param eip: EIP寄存器值
    :param mark: 修改相关寄存器值和其他值的掩码值(2的倍数) (默认0)
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    HDHK_SetProcessCallBackLparamSendX86 = hd.HDHK_SetProcessCallBackLparamSendX86
    HDHK_SetProcessCallBackLparamSendX86.restype = ctypes.c_int64
    HDHK_SetProcessCallBackLparamSendX86.argtypes = [
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_int32
    ]

    # 根据mark值设置需要修改的参数
    if mark & 1:
        l1 = l1 if l1 is not None else 0
    else:
        l1 = 0

    if mark & 2:
        l2 = l2 if l2 is not None else 0
    else:
        l2 = 0

    if mark & 4:
        l3 = l3 if l3 is not None else 0
    else:
        l3 = 0

    if mark & 8:
        l4 = l4 if l4 is not None else 0
    else:
        l4 = 0

    if mark & 16:
        ebp = ebp if ebp is not None else 0
    else:
        ebp = 0

    if mark & 32:
        esp = esp if esp is not None else 0
    else:
        esp = 0

    if mark & 64:
        eip = eip if eip is not None else 0
    else:
        eip = 0

    # 调用C函数
    ret = HDHK_SetProcessCallBackLparamSendX86(
        ctypes.c_int32(窗口序号),
        ctypes.c_int32(l1),
        ctypes.c_int32(l2),
        ctypes.c_int32(l3),
        ctypes.c_int32(l4),
        ctypes.c_int32(ebp),
        ctypes.c_int32(esp),
        ctypes.c_int32(eip),
        ctypes.c_int32(mark)
    )

    return ret

#INT64 HDHK_SetProcessCallBackLparamRecvX86(int 窗口序号, int l1, int l2, int l3, int l4, int ebp, int esp, int eip, int mark );
def HDHOOK_设置拦截Recv返回参数X86(窗口序号: int, l1: int = None, l2: int = None, l3: int = None, l4: int = None, ebp: int = None, esp: int = None, eip: int = None, mark: int = 0) -> int:
    """
    设置回调函数返回值给目标进程（Recv API）
    :param 窗口序号: 窗口序号 (从1开始)
    :param l1: 参数1
    :param l2: 参数2
    :param l3: 参数3
    :param l4: 参数4
    :param ebp: EBP寄存器值
    :param esp: ESP寄存器值
    :param eip: EIP寄存器值
    :param mark: 整数型的网络字节序 如:"127.0.0.1"  那么就需要写成:0x0100007F
    :return:
    """
    hd = Config.get_hd()

    # 定义函数指针类型
    HDHK_SetProcessCallBackLparamRecvX86 = hd.HDHK_SetProcessCallBackLparamRecvX86
    HDHK_SetProcessCallBackLparamRecvX86.restype = ctypes.c_int64
    HDHK_SetProcessCallBackLparamRecvX86.argtypes = [
        ctypes.c_int32,       # 窗口序号
        ctypes.c_int32,       # l1
        ctypes.c_int32,       # l2
        ctypes.c_int32,       # l3
        ctypes.c_int32,       # l4
        ctypes.c_int32,       # ebp
        ctypes.c_int32,       # esp
        ctypes.c_int32,       # eip
        ctypes.c_int32        # mark
    ]

    # 根据mark值设置需要修改的参数
    if mark & 1:
        l1 = l1 if l1 is not None else 0
    else:
        l1 = 0

    if mark & 2:
        l2 = l2 if l2 is not None else 0
    else:
        l2 = 0

    if mark & 4:
        l3 = l3 if l3 is not None else 0
    else:
        l3 = 0

    if mark & 8:
        l4 = l4 if l4 is not None else 0
    else:
        l4 = 0

    if mark & 16:
        ebp = ebp if ebp is not None else 0
    else:
        ebp = 0

    if mark & 32:
        esp = esp if esp is not None else 0
    else:
        esp = 0

    if mark & 64:
        eip = eip if eip is not None else 0
    else:
        eip = 0

    # 调用C函数
    ret = HDHK_SetProcessCallBackLparamRecvX86(
        ctypes.c_int32(窗口序号),
        ctypes.c_int32(l1),
        ctypes.c_int32(l2),
        ctypes.c_int32(l3),
        ctypes.c_int32(l4),
        ctypes.c_int32(ebp),
        ctypes.c_int32(esp),
        ctypes.c_int32(eip),
        ctypes.c_int32(mark)
    )

    return ret

#INT64 HDHK_SetProcessCallBackLparamSendToX86(int 窗口序号, int l1, int l2, int l3, int l4, int l5, int l6, int ebp, int esp, int eip, int mark);
def HDHOOK_设置拦截SendTo返回参数X86(窗口序号: int, l1: int = None, l2: int = None, l3: int = None, l4: int = None, l5: int = None, l6: int = None, ebp: int = None, esp: int = None, eip: int = None, mark: int = 0) -> int:
    """
    设置回调函数返回值给目标进程（SendTo API）
    :param 窗口序号: 窗口序号 (从1开始)
    :param l1: 参数1
    :param l2: 参数2
    :param l3: 参数3
    :param l4: 参数4
    :param l5: 参数5 (端口)
    :param l6: 参数6 (IP地址)
    :param ebp: EBP寄存器值
    :param esp: ESP寄存器值
    :param eip: EIP寄存器值
    :param mark: 整数型的网络字节序 如:"127.0.0.1"  那么就需要写成:0x0100007F
    :return:
    """
    hd = Config.get_hd()

    # 定义函数指针类型
    HDHK_SetProcessCallBackLparamSendToX86 = hd.HDHK_SetProcessCallBackLparamSendToX86
    HDHK_SetProcessCallBackLparamSendToX86.restype = ctypes.c_int64
    HDHK_SetProcessCallBackLparamSendToX86.argtypes = [
        ctypes.c_int32,       # 窗口序号
        ctypes.c_int32,       # l1
        ctypes.c_int32,       # l2
        ctypes.c_int32,       # l3
        ctypes.c_int32,       # l4
        ctypes.c_int32,       # l5
        ctypes.c_int32,       # l6
        ctypes.c_int32,       # ebp
        ctypes.c_int32,       # esp
        ctypes.c_int32,       # eip
        ctypes.c_int32        # mark
    ]

    # 根据mark值设置需要修改的参数
    if mark & 1:
        l1 = l1 if l1 is not None else 0
    else:
        l1 = 0

    if mark & 2:
        l2 = l2 if l2 is not None else 0
    else:
        l2 = 0

    if mark & 4:
        l3 = l3 if l3 is not None else 0
    else:
        l3 = 0

    if mark & 8:
        l4 = l4 if l4 is not None else 0
    else:
        l4 = 0

    if mark & 16:
        ebp = ebp if ebp is not None else 0
    else:
        ebp = 0

    if mark & 32:
        esp = esp if esp is not None else 0
    else:
        esp = 0

    if mark & 64:
        eip = eip if eip is not None else 0
    else:
        eip = 0

    if mark & 128:
        l5 = l5 if l5 is not None else 0
    else:
        l5 = 0

    if mark & 256:
        l6 = l6 if l6 is not None else 0
    else:
        l6 = 0

    # 调用C函数
    ret = HDHK_SetProcessCallBackLparamSendToX86(
        ctypes.c_int32(窗口序号),
        ctypes.c_int32(l1),
        ctypes.c_int32(l2),
        ctypes.c_int32(l3),
        ctypes.c_int32(l4),
        ctypes.c_int32(l5),
        ctypes.c_int32(l6),
        ctypes.c_int32(ebp),
        ctypes.c_int32(esp),
        ctypes.c_int32(eip),
        ctypes.c_int32(mark)
    )

    return ret

#INT64 SetProcessCallBackLparamRecvFromX86(int 窗口序号, int l1, int l2, int l3, int l4, int l5, int l6, int ebp, int esp, int eip, int mark);
def HDHOOK_设置拦截RecvFrom返回参数X86(窗口序号: int, l1: int = None, l2: int = None, l3: int = None, l4: int = None, l5: int = None, l6: int = None, ebp: int = None, esp: int = None, eip: int = None, mark: int = 0) -> int:
    """
    设置回调函数返回值给目标进程（RecvFrom API）
    :param 窗口序号: 窗口序号 (从1开始)
    :param l1: 参数1
    :param l2: 参数2
    :param l3: 参数3
    :param l4: 参数4
    :param l5: 参数5 (端口)
    :param l6: 参数6 (IP地址)
    :param ebp: EBP寄存器值
    :param esp: ESP寄存器值
    :param eip: EIP寄存器值
    :param mark: 修改相关寄存器值和其他值的掩码值(2的倍数)
    :return:
    """
    hd = Config.get_hd()

    # 定义函数指针类型
    HDHK_SetProcessCallBackLparamRecvFromX86 = hd.HDHK_SetProcessCallBackLparamRecvFromX86
    HDHK_SetProcessCallBackLparamRecvFromX86.restype = ctypes.c_int64
    HDHK_SetProcessCallBackLparamRecvFromX86.argtypes = [
        ctypes.c_int32,       # 窗口序号
        ctypes.c_int32,       # l1
        ctypes.c_int32,       # l2
        ctypes.c_int32,       # l3
        ctypes.c_int32,       # l4
        ctypes.c_int32,       # l5
        ctypes.c_int32,       # l6
        ctypes.c_int32,       # ebp
        ctypes.c_int32,       # esp
        ctypes.c_int32,       # eip
        ctypes.c_int32        # mark
    ]

    # 根据mark值设置需要修改的参数
    if mark & 1:
        l1 = l1 if l1 is not None else 0
    else:
        l1 = 0

    if mark & 2:
        l2 = l2 if l2 is not None else 0
    else:
        l2 = 0

    if mark & 4:
        l3 = l3 if l3 is not None else 0
    else:
        l3 = 0

    if mark & 8:
        l4 = l4 if l4 is not None else 0
    else:
        l4 = 0

    if mark & 16:
        ebp = ebp if ebp is not None else 0
    else:
        ebp = 0

    if mark & 32:
        esp = esp if esp is not None else 0
    else:
        esp = 0

    if mark & 64:
        eip = eip if eip is not None else 0
    else:
        eip = 0

    if mark & 128:
        l5 = l5 if l5 is not None else 0
    else:
        l5 = 0

    if mark & 256:
        l6 = l6 if l6 is not None else 0
    else:
        l6 = 0

    # 调用C函数
    ret = HDHK_SetProcessCallBackLparamRecvFromX86(
        ctypes.c_int32(窗口序号),
        ctypes.c_int32(l1),
        ctypes.c_int32(l2),
        ctypes.c_int32(l3),
        ctypes.c_int32(l4),
        ctypes.c_int32(l5),
        ctypes.c_int32(l6),
        ctypes.c_int32(ebp),
        ctypes.c_int32(esp),
        ctypes.c_int32(eip),
        ctypes.c_int32(mark)
    )

    return ret

#INT64 HDHK_SetProcessCallBackLparamSendX64(int 窗口序号, INT64 rcx, INT64 rdx, INT64 r8, INT64 r9, INT64 rbp, INT64 rsp, INT64 rip, int mark);
def HDHOOK_设置拦截Send返回参数X64(窗口序号: int, rcx: int = None, rdx: int = None, r8: int = None, r9: int = None, rbp: int = None, rsp: int = None, rip: int = None, mark: int = 0) -> int:
    """
    设置回调函数返回值给目标进程（Send API）
    :param 窗口序号: 窗口序号 (从1开始)
    :param rcx: 参数1
    :param rdx: 参数2
    :param r8: 参数3
    :param r9: 参数4
    :param rbp: RBP寄存器值
    :param rsp: RSP寄存器值
    :param rip: RIP寄存器值
    :param mark: 修改相关寄存器值和其他值的掩码值(2的倍数)
    :return:
    """
    hd = Config.get_hd()

    # 定义函数指针类型
    HDHK_SetProcessCallBackLparamSendX64 = hd.HDHK_SetProcessCallBackLparamSendX64
    HDHK_SetProcessCallBackLparamSendX64.restype = ctypes.c_int64
    HDHK_SetProcessCallBackLparamSendX64.argtypes = [
        ctypes.c_int32,       # 窗口序号
        ctypes.c_int64,       # rcx
        ctypes.c_int64,       # rdx
        ctypes.c_int64,       # r8
        ctypes.c_int64,       # r9
        ctypes.c_int64,       # rbp
        ctypes.c_int64,       # rsp
        ctypes.c_int64,       # rip
        ctypes.c_int32        # mark
    ]

    # 根据mark值设置需要修改的参数
    if mark & 1:
        rcx = rcx if rcx is not None else 0
    else:
        rcx = 0

    if mark & 2:
        rdx = rdx if rdx is not None else 0
    else:
        rdx = 0

    if mark & 4:
        r8 = r8 if r8 is not None else 0
    else:
        r8 = 0

    if mark & 8:
        r9 = r9 if r9 is not None else 0
    else:
        r9 = 0

    if mark & 16:
        rbp = rbp if rbp is not None else 0
    else:
        rbp = 0

    if mark & 32:
        rsp = rsp if rsp is not None else 0
    else:
        rsp = 0

    if mark & 64:
        rip = rip if rip is not None else 0
    else:
        rip = 0



    # 调用C函数
    ret = HDHK_SetProcessCallBackLparamSendX64(
        ctypes.c_int32(窗口序号),
        ctypes.c_int64(rcx),
        ctypes.c_int64(rdx),
        ctypes.c_int64(r8),
        ctypes.c_int64(r9),
        ctypes.c_int64(rbp),
        ctypes.c_int64(rsp),
        ctypes.c_int64(rip),
        ctypes.c_int32(mark)
    )

    return ret

#INT64 HDHK_SetProcessCallBackLparamRecvX64(int 窗口序号, INT64 rcx, INT64 rdx, INT64 r8, INT64 r9, INT64 rbp, INT64 rsp, INT64 rip, int mark);
def HDHOOK_设置拦截Recv返回参数X64(窗口序号: int, rcx: int = None, rdx: int = None, r8: int = None, r9: int = None, rbp: int = None, rsp: int = None, rip: int = None, mark: int = 0) -> int:
    """
    设置回调函数返回值给目标进程（Recv API）
    :param 窗口序号: 窗口序号 (从1开始)
    :param rcx: 参数1
    :param rdx: 参数2
    :param r8: 参数3
    :param r9: 参数4
    :param rbp: RBP寄存器值
    :param rsp: RSP寄存器值
    :param rip: RIP寄存器值
    :param mark: 修改相关寄存器值和其他值的掩码值(2的倍数)
    :return:
    """
    hd = Config.get_hd()

    # 定义函数指针类型
    HDHK_SetProcessCallBackLparamRecvX64 = hd.HDHK_SetProcessCallBackLparamRecvX64
    HDHK_SetProcessCallBackLparamRecvX64.restype = ctypes.c_int64
    HDHK_SetProcessCallBackLparamRecvX64.argtypes = [
        ctypes.c_int32,       # 窗口序号
        ctypes.c_int64,       # rcx
        ctypes.c_int64,       # rdx
        ctypes.c_int64,       # r8
        ctypes.c_int64,       # r9
        ctypes.c_int64,       # rbp
        ctypes.c_int64,       # rsp
        ctypes.c_int64,       # rip
        ctypes.c_int32        # mark
    ]

    # 根据mark值设置需要修改的参数
    if mark & 1:
        rcx = rcx if rcx is not None else 0
    else:
        rcx = 0

    if mark & 2:
        rdx = rdx if rdx is not None else 0
    else:
        rdx = 0

    if mark & 4:
        r8 = r8 if r8 is not None else 0
    else:
        r8 = 0

    if mark & 8:
        r9 = r9 if r9 is not None else 0
    else:
        r9 = 0

    if mark & 16:
        rbp = rbp if rbp is not None else 0
    else:
        rbp = 0

    if mark & 32:
        rsp = rsp if rsp is not None else 0
    else:
        rsp = 0

    if mark & 64:
        rip = rip if rip is not None else 0
    else:
        rip = 0



    # 调用C函数
    ret = HDHK_SetProcessCallBackLparamRecvX64(
        ctypes.c_int32(窗口序号),
        ctypes.c_int64(rcx),
        ctypes.c_int64(rdx),
        ctypes.c_int64(r8),
        ctypes.c_int64(r9),
        ctypes.c_int64(rbp),
        ctypes.c_int64(rsp),
        ctypes.c_int64(rip),
        ctypes.c_int32(mark)
    )

    return ret

#INT64 SetProcessCallBackLparamSendToX64(int 窗口序号, INT64 rcx, INT64 rdx, INT64 r8, INT64 r9, INT64 l5, INT64 l6, INT64 rbp, INT64 rsp, INT64 rip, int mark);
def HDHOOK_设置拦截SendTo返回参数X64(窗口序号: int, rcx: int = None, rdx: int = None, r8: int = None, r9: int = None, l5: int = None, l6: int = None, rbp: int = None, rsp: int = None, rip: int = None, mark: int = 0) -> int:
    """
    设置回调函数返回值给目标进程（SendTo API）
    :param 窗口序号: 窗口序号 (从1开始)
    :param rcx: 参数1
    :param rdx: 参数2
    :param r8: 参数3
    :param r9: 参数4
    :param l5: 参数5 (端口)
    :param l6: 参数6 (IP地址)
    :param rbp: RBP寄存器值
    :param rsp: RSP寄存器值
    :param rip: RIP寄存器值
    :param mark: 修改相关寄存器值和其他值的掩码值(2的倍数)
    :return:
    """
    hd = Config.get_hd()

    # 定义函数指针类型
    HDHK_SetProcessCallBackLparamSendToX64 = hd.HDHK_SetProcessCallBackLparamSendToX64
    HDHK_SetProcessCallBackLparamSendToX64.restype = ctypes.c_int64
    HDHK_SetProcessCallBackLparamSendToX64.argtypes = [
        ctypes.c_int32,       # 窗口序号
        ctypes.c_int64,       # rcx
        ctypes.c_int64,       # rdx
        ctypes.c_int64,       # r8
        ctypes.c_int64,       # r9
        ctypes.c_int64,       # l5
        ctypes.c_int64,       # l6
        ctypes.c_int64,       # rbp
        ctypes.c_int64,       # rsp
        ctypes.c_int64,       # rip
        ctypes.c_int32        # mark
    ]

    # 根据mark值设置需要修改的参数
    if mark & 1:
        rcx = rcx if rcx is not None else 0
    else:
        rcx = 0

    if mark & 2:
        rdx = rdx if rdx is not None else 0
    else:
        rdx = 0

    if mark & 4:
        r8 = r8 if r8 is not None else 0
    else:
        r8 = 0

    if mark & 8:
        r9 = r9 if r9 is not None else 0
    else:
        r9 = 0

    if mark & 16:
        rbp = rbp if rbp is not None else 0
    else:
        rbp = 0

    if mark & 32:
        rsp = rsp if rsp is not None else 0
    else:
        rsp = 0

    if mark & 64:
        rip = rip if rip is not None else 0
    else:
        rip = 0

    if mark & 128:
        l5 = l5 if l5 is not None else 0
    else:
        l5 = 0

    if mark & 256:
        l6 = l6 if l6 is not None else 0
    else:
        l6 = 0

    # 调用C函数
    ret = HDHK_SetProcessCallBackLparamSendToX64(
        ctypes.c_int32(窗口序号),
        ctypes.c_int64(rcx),
        ctypes.c_int64(rdx),
        ctypes.c_int64(r8),
        ctypes.c_int64(r9),
        ctypes.c_int64(l5),
        ctypes.c_int64(l6),
        ctypes.c_int64(rbp),
        ctypes.c_int64(rsp),
        ctypes.c_int64(rip),
        ctypes.c_int32(mark)
    )

    return ret

#INT64 HDHK_SetProcessCallBackLparamRecvFromX64(int 窗口序号, INT64 rcx, INT64 rdx, INT64 r8, INT64 r9, INT64 l5, INT64 l6, INT64 rbp, INT64 rsp, INT64 rip, int mark);
def HDHOOK_设置拦截RecvFrom返回参数X64(窗口序号: int, rcx: int = None, rdx: int = None, r8: int = None, r9: int = None, l5: int = None, l6: int = None, rbp: int = None, rsp: int = None, rip: int = None, mark: int = 0) -> int:
    """
    设置回调函数返回值给目标进程（RecvFrom API）
    :param 窗口序号: 窗口序号 (从1开始)
    :param rcx: 参数1
    :param rdx: 参数2
    :param r8: 参数3
    :param r9: 参数4
    :param l5: 参数5 (端口)
    :param l6: 参数6 (IP地址)
    :param rbp: RBP寄存器值
    :param rsp: RSP寄存器值
    :param rip: RIP寄存器值
    :param mark: 修改相关寄存器值和其他值的掩码值(2的倍数)
    :return:
    """
    hd = Config.get_hd()

    # 定义函数指针类型
    HDHK_SetProcessCallBackLparamRecvFromX64 = hd.HDHK_SetProcessCallBackLparamRecvFromX64
    HDHK_SetProcessCallBackLparamRecvFromX64.restype = ctypes.c_int64
    HDHK_SetProcessCallBackLparamRecvFromX64.argtypes = [
        ctypes.c_int32,       # 窗口序号
        ctypes.c_int64,       # rcx
        ctypes.c_int64,       # rdx
        ctypes.c_int64,       # r8
        ctypes.c_int64,       # r9
        ctypes.c_int64,       # l5
        ctypes.c_int64,       # l6
        ctypes.c_int64,       # rbp
        ctypes.c_int64,       # rsp
        ctypes.c_int64,       # rip
        ctypes.c_int32        # mark
    ]

    # 根据mark值设置需要修改的参数
    if mark & 1:
        rcx = rcx if rcx is not None else 0
    else:
        rcx = 0

    if mark & 2:
        rdx = rdx if rdx is not None else 0
    else:
        rdx = 0

    if mark & 4:
        r8 = r8 if r8 is not None else 0
    else:
        r8 = 0

    if mark & 8:
        r9 = r9 if r9 is not None else 0
    else:
        r9 = 0

    if mark & 16:
        rbp = rbp if rbp is not None else 0
    else:
        rbp = 0

    if mark & 32:
        rsp = rsp if rsp is not None else 0
    else:
        rsp = 0

    if mark & 64:
        rip = rip if rip is not None else 0
    else:
        rip = 0

    if mark & 128:
        l5 = l5 if l5 is not None else 0
    else:
        l5 = 0

    if mark & 256:
        l6 = l6 if l6 is not None else 0
    else:
        l6 = 0

    # 调用C函数
    ret = HDHK_SetProcessCallBackLparamRecvFromX64(
        ctypes.c_int32(窗口序号),
        ctypes.c_int64(rcx),
        ctypes.c_int64(rdx),
        ctypes.c_int64(r8),
        ctypes.c_int64(r9),
        ctypes.c_int64(l5),
        ctypes.c_int64(l6),
        ctypes.c_int64(rbp),
        ctypes.c_int64(rsp),
        ctypes.c_int64(rip),
        ctypes.c_int32(mark)
    )

    return ret

# INT64 __stdcall HDHK_Hook(int 窗口序号, INT64 hook地址, int 破坏字节, INT64 回调地址, INT64 附加参数, BOOL 是否主线程调用);
def HDHOOK_挂钩(窗口序号: int, hook地址: int, 破坏字节: int, 回调地址: HD_HandleCallBackFunTypeHook_stdcall, 附加参数: int, 是否主线程调用: bool = False) -> int:
    """
    任意HOOK(内置插件)X86X64
    :param 窗口序号: 窗口序号 (从1开始)
    :param hook地址: 当前HOOK的目标地址
    :param 破坏字节: 涉及到的汇编字节数
    :param 回调地址: 请查询手册将写好的函数填进来
    :param 附加参数: 自定义参数,此参数会传递给回调函数
    :param 是否主线程调用: 需要开启才开启,一般默认就行 (默认False)
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    HDHK_Hook = hd.HDHK_Hook
    HDHK_Hook.restype = ctypes.c_int64
    HDHK_Hook.argtypes = [ctypes.c_int32, ctypes.c_int64, ctypes.c_int32, ctypes.c_int64, ctypes.c_int64, ctypes.c_bool]

    HandleCallBackFunTypeHook_stdcall = HD_HandleCallBackFunTypeHook_stdcall(回调地址)
    HandleCallBackFunTypeHook_stdcall_ptr = ctypes.c_int64(ctypes.cast(HandleCallBackFunTypeHook_stdcall, ctypes.c_void_p).value) if HandleCallBackFunTypeHook_stdcall else ctypes.c_int64(0)

    ret = HDHK_Hook(
        ctypes.c_int32(窗口序号),
        ctypes.c_int64(hook地址),
        ctypes.c_int32(破坏字节),
        HandleCallBackFunTypeHook_stdcall_ptr,
        ctypes.c_int64(附加参数),
        ctypes.c_bool(是否主线程调用)
    )

    return ret


# INT64 __stdcall HDHK_HookEx (__int32 窗口序号, char *所属模块名字, __int64 hook地址, __int32 破坏字节, __int64 回调地址, __int64 附加参数, BOOL 是否主线程调用 = FALSE);
def HDHOOK_挂钩Ex(窗口序号: int,模块名字:str, hook地址: int, 破坏字节: int, 回调地址: HD_HandleCallBackFunTypeHook_stdcall, 附加参数: int, 是否主线程调用: bool = False) -> int:
    """
    任意HOOK(内置插件)X64 扩展版本1
    :param 窗口序号: 窗口序号 (从1开始)
    :param 模块名字: 当前HOOK地址所属那个模块  当前HOOK地址所属那个模块  可以不指定 为0就行 但是建议指定
    :param hook地址: 当前HOOK的目标地址
    :param 破坏字节: 涉及到的汇编字节数
    :param 回调地址: 请查询手册将写好的函数填进来
    :param 附加参数: 自定义参数,此参数会传递给回调函数
    :param 是否主线程调用: 需要开启才开启,一般默认就行 (默认False)
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    HDHK_HookEx = hd.HDHK_HookEx
    HDHK_HookEx.restype = ctypes.c_int64
    HDHK_HookEx.argtypes = [ctypes.c_int32,ctypes.c_char_p, ctypes.c_int64, ctypes.c_int32, ctypes.c_int64, ctypes.c_int64, ctypes.c_bool]

    HandleCallBackFunTypeHook_stdcall = HD_HandleCallBackFunTypeHook_stdcall(回调地址)
    HandleCallBackFunTypeHook_stdcall_ptr = ctypes.c_int64(ctypes.cast(HandleCallBackFunTypeHook_stdcall, ctypes.c_void_p).value) if HandleCallBackFunTypeHook_stdcall else ctypes.c_int64(0)

    ret = HDHK_HookEx(
        ctypes.c_int32(窗口序号),
        auto_encode(模块名字),
        ctypes.c_int64(hook地址),
        ctypes.c_int32(破坏字节),
        HandleCallBackFunTypeHook_stdcall_ptr,
        ctypes.c_int64(附加参数),
        ctypes.c_bool(是否主线程调用)
    )

    return ret

# INT64 __stdcall HDHK_HookExx(__int32 窗口序号, char *所属模块名字, __int64 模块首地址, __int32 模块大小, __int64 hook地址, __int32 破坏字节, __int64 回调地址, __int64 附加参数, BOOL 是否主线程调用 = FALSE);
def HDHOOK_挂钩Exx(窗口序号: int,模块名字:str, 模块首地址: int, 模块大小: int, hook地址: int, 破坏字节: int, 回调地址: HD_HandleCallBackFunTypeHook_stdcall, 附加参数: int, 是否主线程调用: bool = False) -> int:
    """
    任意HOOK(内置插件)X64 扩展版本2
    :param 窗口序号: 窗口序号 (从1开始)
    :param 模块名字: 当前HOOK地址所属那个模块  当前HOOK地址所属那个模块  可以不指定 为0就行 但是建议指定
    :param 模块首地址:HOOK地址所属模块的模块基地址
    :param 模块大小:HOOK地址所属模块的模块大小字节
    :param hook地址: 当前HOOK的目标地址
    :param 破坏字节: 涉及到的汇编字节数
    :param 回调地址: 请查询手册将写好的函数填进来
    :param 附加参数: 自定义参数,此参数会传递给回调函数
    :param 是否主线程调用: 需要开启才开启,一般默认就行 (默认False)
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    HDHK_HookExx = hd.HDHK_HookExx
    HDHK_HookExx.restype = ctypes.c_int64
    HDHK_HookExx.argtypes = [ctypes.c_int32,ctypes.c_char_p,ctypes.c_int64,ctypes.c_int32, ctypes.c_int64, ctypes.c_int32, ctypes.c_int64, ctypes.c_int64, ctypes.c_bool]

    HandleCallBackFunTypeHook_stdcall = HD_HandleCallBackFunTypeHook_stdcall(回调地址)
    HandleCallBackFunTypeHook_stdcall_ptr = ctypes.c_int64(ctypes.cast(HandleCallBackFunTypeHook_stdcall, ctypes.c_void_p).value) if HandleCallBackFunTypeHook_stdcall else ctypes.c_int64(0)

    ret = HDHK_HookExx(
        ctypes.c_int32(窗口序号),
        auto_encode(模块名字),
        ctypes.c_int64(模块首地址),
        ctypes.c_int32(模块大小),
        ctypes.c_int64(hook地址),
        ctypes.c_int32(破坏字节),
        HandleCallBackFunTypeHook_stdcall_ptr,
        ctypes.c_int64(附加参数),
        ctypes.c_bool(是否主线程调用)
    )

    return ret

# INT64 __stdcall HDHK_HookExxx(__int32 窗口序号, __int64 hook地址, char *所属模块名字, __int64 jmp13空白地址, __int64 保留汇编地址, __int32 破坏字节, __int64 回调地址, __int64 附加参数, BOOL 是否主线程调用 = FALSE);
def HDHOOK_挂钩Exxx(窗口序号: int,模块名字:str, jmp13空白地址: int, 保留汇编地址: int, hook地址: int, 破坏字节: int, 回调地址: HD_HandleCallBackFunTypeHook_stdcall, 附加参数: int, 是否主线程调用: bool = False) -> int:
    """
    任意HOOK(内置插件)X64 扩展版本3
    :param 窗口序号: 窗口序号 (从1开始)
    :param 模块名字: 当前HOOK地址所属那个模块  当前HOOK地址所属那个模块  可以不指定 为0就行 但是建议指定
    :param jmp13空白地址:在当前模块的代码地址找一个空白空间 大小为13字节 用于存储jmp一些指令
    :param 保留汇编地址:用来存储破坏字节数量 +5 字节大小的空白空间的首地址 一般这个地址位于当前所属模块代码空白空间
    :param hook地址: 当前HOOK的目标地址
    :param 破坏字节: 涉及到的汇编字节数
    :param 回调地址: 请查询手册将写好的函数填进来
    :param 附加参数: 自定义参数,此参数会传递给回调函数
    :param 是否主线程调用: 需要开启才开启,一般默认就行 (默认False)
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    HDHK_HookExxx = hd.HDHK_HookExxx
    HDHK_HookExxx.restype = ctypes.c_int64
    HDHK_HookExxx.argtypes = [ctypes.c_int32,ctypes.c_char_p,ctypes.c_int64,ctypes.c_int64, ctypes.c_int64, ctypes.c_int32, ctypes.c_int64, ctypes.c_int64, ctypes.c_bool]

    HandleCallBackFunTypeHook_stdcall = HD_HandleCallBackFunTypeHook_stdcall(回调地址)
    HandleCallBackFunTypeHook_stdcall_ptr = ctypes.c_int64(ctypes.cast(HandleCallBackFunTypeHook_stdcall, ctypes.c_void_p).value) if HandleCallBackFunTypeHook_stdcall else ctypes.c_int64(0)

    ret = HDHK_HookExxx(
        ctypes.c_int32(窗口序号),
        auto_encode(模块名字),
        ctypes.c_int64(jmp13空白地址),
        ctypes.c_int64(保留汇编地址),
        ctypes.c_int64(hook地址),
        ctypes.c_int32(破坏字节),
        HandleCallBackFunTypeHook_stdcall_ptr,
        ctypes.c_int64(附加参数),
        ctypes.c_bool(是否主线程调用)
    )

    return ret


# INT64 __stdcall HDHK_PauseHook(int 窗口序号, INT64 hook地址, BOOL 是否主线程调用);
def HDHOOK_暂停挂钩(窗口序号: int, hook地址: int, 是否主线程调用: bool = False) -> int:
    """
    暂停任意HOOK(内置插件)X86X64
    :param 窗口序号: 窗口序号 (从1开始)
    :param hook地址: 当前HOOK的目标地址
    :param 是否主线程调用: 需要开启才开启,一般默认就行 (默认False)
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    HDHK_PauseHook = hd.HDHK_PauseHook
    HDHK_PauseHook.restype = ctypes.c_int64
    HDHK_PauseHook.argtypes = [ctypes.c_int32, ctypes.c_int64, ctypes.c_bool]

    ret = HDHK_PauseHook(
        ctypes.c_int32(窗口序号),
        ctypes.c_int64(hook地址),
        ctypes.c_bool(是否主线程调用)
    )

    return ret

# INT64 __stdcall HDHK_RecoverHook(int 窗口序号, INT64 hook地址, BOOL 是否主线程调用);
def HDHOOK_恢复挂钩(窗口序号: int, hook地址: int, 是否主线程调用: bool = False) -> int:
    """
    恢复任意HOOK(内置插件)X86X64
    :param 窗口序号: 窗口序号 (从1开始)
    :param hook地址: 当前HOOK的目标地址
    :param 是否主线程调用: 需要开启才开启,一般默认就行 (默认False)
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    HDHK_ResumeHook = hd.HDHK_RecoverHook
    HDHK_ResumeHook.restype = ctypes.c_int64
    HDHK_ResumeHook.argtypes = [ctypes.c_int32, ctypes.c_int64, ctypes.c_bool]

    ret = HDHK_ResumeHook(
        ctypes.c_int32(窗口序号),
        ctypes.c_int64(hook地址),
        ctypes.c_bool(是否主线程调用)
    )

    return ret

# INT64 __stdcall HDHK_UnHook(int 窗口序号, INT64 hook地址, BOOL 是否主线程调用);
def HDHOOK_卸载挂钩(窗口序号: int, hook地址: int, 是否主线程调用: bool = False) -> int:
    """
    卸载任意HOOK(内置插件)X86X64
    :param 窗口序号: 窗口序号 (从1开始)
    :param hook地址: 当前HOOK的目标地址
    :param 是否主线程调用: 需要开启才开启,一般默认就行 (默认False)
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    HDHK_UnHook = hd.HDHK_UnHook
    HDHK_UnHook.restype = ctypes.c_int64
    HDHK_UnHook.argtypes = [ctypes.c_int32, ctypes.c_int64, ctypes.c_bool]

    ret = HDHK_UnHook(
        ctypes.c_int32(窗口序号),
        ctypes.c_int64(hook地址),
        ctypes.c_bool(是否主线程调用)
    )

    return ret

# INT64 __stdcall HDHK_SetProcessHookCallBackLparam(int 窗口序号, int 插件序号, INT64 raxOreax, INT64 rbxOrebx, INT64 rcxOrecx, INT64 rdxOredx, INT64 rbpOrebp, INT64 rspOresp, INT64 rsiOresi, INT64 rdiOredi, INT64 r8, INT64 r9, INT64 r10, INT64 r11, INT64 r12, INT64 r13, INT64 r14, INT64 r15, INT64 rip, int mark);
def HDHOOK_设置挂钩返回参数(窗口序号: int, 插件序号: int, raxOreax: int, rbxOrebx: int, rcxOrecx: int, rdxOredx: int, rbpOrebp: int, rspOresp: int, rsiOresi: int, rdiOredi: int, r8: int, r9: int, r10: int, r11: int, r12: int, r13: int, r14: int, r15: int, rip: int, mark: int) -> int:
    """
    设置HOOK返回参数
    :param 窗口序号: 窗口序号 (从1开始)
    :param 插件序号: 内部自动传递
    :param raxOreax: RAX/EAX寄存器值
    :param rbxOrebx: RBX/EBX寄存器值
    :param rcxOrecx: RCX/ECX寄存器值
    :param rdxOredx: RDX/EDX寄存器值
    :param rbpOrebp: RBP/EBP寄存器值
    :param rspOresp: RSP/ESP寄存器值
    :param rsiOresi: RSI/ESI寄存器值
    :param rdiOredi: RDI/EDI寄存器值
    :param r8: R8寄存器值
    :param r9: R9寄存器值
    :param r10: R10寄存器值
    :param r11: R11寄存器值
    :param r12: R12寄存器值
    :param r13: R13寄存器值
    :param r14: R14寄存器值
    :param r15: R15寄存器值
    :param rip: RIP寄存器值
    :param mark: 标记值
    :return: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    HDHK_SetProcessHookCallBackLparam = hd.HDHK_SetProcessHookCallBackLparam
    HDHK_SetProcessHookCallBackLparam.restype = ctypes.c_int64
    HDHK_SetProcessHookCallBackLparam.argtypes = [
        ctypes.c_int32, ctypes.c_int32, ctypes.c_int64, ctypes.c_int64,
        ctypes.c_int64, ctypes.c_int64, ctypes.c_int64, ctypes.c_int64,
        ctypes.c_int64, ctypes.c_int64, ctypes.c_int64, ctypes.c_int64,
        ctypes.c_int64, ctypes.c_int64, ctypes.c_int64, ctypes.c_int64,
        ctypes.c_int64, ctypes.c_int64, ctypes.c_int64, ctypes.c_int32
    ]

    ret = HDHK_SetProcessHookCallBackLparam(
        ctypes.c_int32(窗口序号),
        ctypes.c_int32(插件序号),
        ctypes.c_int64(raxOreax),
        ctypes.c_int64(rbxOrebx),
        ctypes.c_int64(rcxOrecx),
        ctypes.c_int64(rdxOredx),
        ctypes.c_int64(rbpOrebp),
        ctypes.c_int64(rspOresp),
        ctypes.c_int64(rsiOresi),
        ctypes.c_int64(rdiOredi),
        ctypes.c_int64(r8),
        ctypes.c_int64(r9),
        ctypes.c_int64(r10),
        ctypes.c_int64(r11),
        ctypes.c_int64(r12),
        ctypes.c_int64(r13),
        ctypes.c_int64(r14),
        ctypes.c_int64(r15),
        ctypes.c_int64(rip),
        ctypes.c_int32(mark)
    )

    return ret


from .config import Config, ctypes
from .config import auto_encode

def HDYOLOV_添加模型(版本: int, 模型数据: bytes, 参数数据: bytes, 图片大小: int = 640, 是否GPU: bool = False, 密码: str = "") -> int:
    """
    添加YOLOV（ncnn.bin和ncnn.param）模型文件（从内存中加载模型）
    需要调用HCHD_LoadDrv2传递参数4来安装YOLOV组件模块
    
    Args:
        版本: YOLOV版本，支持5、8、10、11版本
        模型数据: ncnn.bin模型文件的二进制数据 (bytes) - 字节数组，如：b'\x01\x02\x03' 或 bytes([1, 2, 3])
        参数数据: ncnn.param模型文件的二进制数据 (bytes) - 字节数组，如：b'\x01\x02\x03' 或 bytes([1, 2, 3])
        图片大小: 训练时候的图片大小，默认640
        是否GPU: 是否GPU识别，默认False
        密码: 密码，默认空
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCYOLO_AddModel = hd.HCYOLO_AddModel
    HCYOLO_AddModel.restype = ctypes.c_int64
    HCYOLO_AddModel.argtypes = [ctypes.c_int32, ctypes.c_void_p, ctypes.c_int32, ctypes.c_void_p, ctypes.c_int32, ctypes.c_int32, ctypes.c_bool, ctypes.c_char_p]
    
    模型数据缓冲区 = ctypes.create_string_buffer(模型数据)
    参数数据缓冲区 = ctypes.create_string_buffer(参数数据)
    
    ret = HCYOLO_AddModel(
        ctypes.c_int32(版本),
        ctypes.cast(模型数据缓冲区, ctypes.c_void_p),
        ctypes.c_int32(len(模型数据)),
        ctypes.cast(参数数据缓冲区, ctypes.c_void_p),
        ctypes.c_int32(len(参数数据)),
        ctypes.c_int32(图片大小),
        ctypes.c_bool(是否GPU),
        auto_encode(密码) if 密码 else None
    )
    return ret

def HDYOLOV_添加模型文件(版本: int, 模型文件名: str, 参数文件名: str, 图片大小: int = 640, 是否GPU: bool = False, 密码: str = "") -> int:
    """
    添加YOLOV（ncnn.bin和ncnn.param）模型文件（从文件中加载模型）
    需要调用HCHD_LoadDrv2传递参数4来安装YOLOV组件模块
    
    Args:
        版本: YOLOV版本，支持5、8、10、11版本
        模型文件名: ncnn.bin模型文件名（支持绝对路径或相对路径）
        参数文件名: ncnn.param模型文件名（支持绝对路径或相对路径）
        图片大小: 训练时候的图片大小，默认640
        是否GPU: 是否GPU识别，默认False
        密码: 密码，默认空
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCYOLO_AddModelFile = hd.HCYOLO_AddModelFile
    HCYOLO_AddModelFile.restype = ctypes.c_int64
    HCYOLO_AddModelFile.argtypes = [ctypes.c_int32, ctypes.c_char_p, ctypes.c_char_p, ctypes.c_int32, ctypes.c_bool, ctypes.c_char_p]
    
    ret = HCYOLO_AddModelFile(
        ctypes.c_int32(版本),
        auto_encode(模型文件名),
        auto_encode(参数文件名),
        ctypes.c_int32(图片大小),
        ctypes.c_bool(是否GPU),
        auto_encode(密码) if 密码 else None
    )
    return ret

def HDYOLOV_识别(窗口序号: int, 置信度: float = 0.7, IOU阈值: float = 0.4, 是否调试: bool = False) -> int:
    """
    YOLOV识别（后台截图）
    
    Args:
        窗口序号: 窗口序号（从1开始）
        置信度: 置信度，默认0.7
        IOU阈值: IOU阈值，默认0.4
        是否调试: 是否调试模式，默认False
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCYOLO_Detect = hd.HCYOLO_Detect
    HCYOLO_Detect.restype = ctypes.c_int64
    HCYOLO_Detect.argtypes = [ctypes.c_int32, ctypes.c_float, ctypes.c_float, ctypes.c_bool]
    
    ret = HCYOLO_Detect(
        ctypes.c_int32(窗口序号),
        ctypes.c_float(置信度),
        ctypes.c_float(IOU阈值),
        ctypes.c_bool(是否调试)
    )
    return ret

def HDYOLOV_识别从文件(窗口序号: int, 图片路径: str, 置信度: float = 0.7, IOU阈值: float = 0.4, 是否调试: bool = False) -> int:
    """
    YOLOV识别（从文件）
    
    Args:
        窗口序号: 窗口序号（从1开始）
        图片路径: 图片文件路径
        置信度: 置信度，默认0.7
        IOU阈值: IOU阈值，默认0.4
        是否调试: 是否调试模式，默认False
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCYOLO_DetectFromFile = hd.HCYOLO_DetectFromFile
    HCYOLO_DetectFromFile.restype = ctypes.c_int64
    HCYOLO_DetectFromFile.argtypes = [ctypes.c_int32, ctypes.c_char_p, ctypes.c_float, ctypes.c_float, ctypes.c_bool]
    
    ret = HCYOLO_DetectFromFile(
        ctypes.c_int32(窗口序号),
        auto_encode(图片路径),
        ctypes.c_float(置信度),
        ctypes.c_float(IOU阈值),
        ctypes.c_bool(是否调试)
    )
    return ret

def HDYOLOV_识别从内存(窗口序号: int, 图片数据: bytes, 置信度: float = 0.7, IOU阈值: float = 0.4, 是否调试: bool = False) -> int:
    """
    YOLOV识别（从内存）
    
    Args:
        窗口序号: 窗口序号（从1开始）
        图片数据: 图片二进制数据 (bytes) - 字节数组，如：b'\x01\x02\x03' 或 bytes([1, 2, 3])
        置信度: 置信度，默认0.7
        IOU阈值: IOU阈值，默认0.4
        是否调试: 是否调试模式，默认False
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCYOLO_DetectFromMemory = hd.HCYOLO_DetectFromMemory
    HCYOLO_DetectFromMemory.restype = ctypes.c_int64
    HCYOLO_DetectFromMemory.argtypes = [ctypes.c_int32, ctypes.c_void_p, ctypes.c_int32, ctypes.c_float, ctypes.c_float, ctypes.c_bool]
    
    图片数据缓冲区 = ctypes.create_string_buffer(图片数据)
    
    ret = HCYOLO_DetectFromMemory(
        ctypes.c_int32(窗口序号),
        ctypes.cast(图片数据缓冲区, ctypes.c_void_p),
        ctypes.c_int32(len(图片数据)),
        ctypes.c_float(置信度),
        ctypes.c_float(IOU阈值),
        ctypes.c_bool(是否调试)
    )
    return ret

def HDYOLOV_范围识别(窗口序号: int, X坐标: int, Y坐标: int, 宽度: int, 高度: int, 置信度: float = 0.7, IOU阈值: float = 0.4, 是否调试: bool = False) -> int:
    """
    YOLOV范围识别（指定区域后台截图）
    
    Args:
        窗口序号: 窗口序号（从1开始）
        X坐标: 区域起始X坐标
        Y坐标: 区域起始Y坐标
        宽度: 区域宽度
        高度: 区域高度
        置信度: 置信度，默认0.7
        IOU阈值: IOU阈值，默认0.4
        是否调试: 是否调试模式，默认False
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCYOLO_DetectRange = hd.HCYOLO_DetectRange
    HCYOLO_DetectRange.restype = ctypes.c_int64
    HCYOLO_DetectRange.argtypes = [ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_float, ctypes.c_float, ctypes.c_bool]
    
    ret = HCYOLO_DetectRange(
        ctypes.c_int32(窗口序号),
        ctypes.c_int32(X坐标),
        ctypes.c_int32(Y坐标),
        ctypes.c_int32(宽度),
        ctypes.c_int32(高度),
        ctypes.c_float(置信度),
        ctypes.c_float(IOU阈值),
        ctypes.c_bool(是否调试)
    )
    return ret

def HDYOLOV_移除模型() -> int:
    """
    移除YOLOV模型
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCYOLO_RemoveModel = hd.HCYOLO_RemoveModel
    HCYOLO_RemoveModel.restype = ctypes.c_int64
    HCYOLO_RemoveModel.argtypes = []
    
    ret = HCYOLO_RemoveModel()
    return ret

def HDYOLOV_设置标签(标签列表: str) -> int:
    """
    设置YOLOV识别标签
    
    Args:
        标签列表: 标签列表字符串，如："person,car,bicycle"
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCYOLO_SetLabel = hd.HCYOLO_SetLabel
    HCYOLO_SetLabel.restype = ctypes.c_int64
    HCYOLO_SetLabel.argtypes = [ctypes.c_char_p]
    
    ret = HCYOLO_SetLabel(auto_encode(标签列表))
    return ret


from .config import Config, ctypes
from .config import auto_encode

# 回调函数模板

# HD多线程_初始化流程回调
def update_ui_callback(windows_index: int, step_text: bytes, end1: int, pause1: int, thread_state1: int, end2: int, pause2: int, thread_state2: int) -> int:
    """
    更新UI回调函数
    
    Args:
        windows_index: 窗口索引
        step_text: 步骤文本 (bytes) - C接口传递的字节数组，需要解码为字符串使用
        end1: 结束状态1
        pause1: 暂停状态1
        thread_state1: 线程状态1
        end2: 结束状态2
        pause2: 暂停状态2
        thread_state2: 线程状态2
    
    Returns:
        int: 返回值
    """
    # C接口传递的char*在Python中是bytes，需要解码为字符串
    text_str = step_text.decode('utf-8', errors='ignore') if step_text else ""
    print(f"Update UI callback called with window index: {windows_index}, step text: {text_str}")
    return 0

def update_ui_callback_ex(windows_index: int, step_text: bytes, lparam: int, m_end1: int, m_pause1: int, thread_state1: int, m_end2: int, m_pause2: int, thread_state2: int) -> int:
    """
    更新UI回调函数扩展版
    
    Args:
        windows_index: 窗口索引
        step_text: 步骤文本 (bytes) - C接口传递的字节数组，需要解码为字符串使用
        lparam: 参数
        m_end1: 结束状态1
        m_pause1: 暂停状态1
        thread_state1: 线程状态1
        m_end2: 结束状态2
        m_pause2: 暂停状态2
        thread_state2: 线程状态2
    
    Returns:
        int: 返回值
    """
    # C接口传递的char*在Python中是bytes，需要解码为字符串
    text_str = step_text.decode('utf-8', errors='ignore') if step_text else ""
    print(f"Update UI callback EX called with window index: {windows_index}, step text: {text_str}")
    return 0

def login_callback(windows_index: int) -> int:
    """
    登录回调函数
    
    Args:
        windows_index: 窗口索引
    
    Returns:
        int: 返回值
    """
    print(f"Login callback called with window index: {windows_index}")
    return 0

def first_callback(windows_index: int) -> int:
    """
    第一步回调函数
    
    Args:
        windows_index: 窗口索引
    
    Returns:
        int: 返回值
    """
    print(f"First callback called with window index: {windows_index}")
    return 0

def second_callback(windows_index: int) -> int:
    """
    第二步回调函数
    
    Args:
        windows_index: 窗口索引
    
    Returns:
        int: 返回值
    """
    print(f"Second callback called with window index: {windows_index}")
    return 0

def end_callback(windows_index: int) -> int:
    """
    结束回调函数
    
    Args:
        windows_index: 窗口索引
    
    Returns:
        int: 返回值
    """
    print(f"End callback called with window index: {windows_index}")
    return 0

def restart_pre_callback(windows_index: int) -> int:
    """
    重启前回调函数
    
    Args:
        windows_index: 窗口索引
    
    Returns:
        int: 返回值
    """
    print(f"Restart pre callback called with window index: {windows_index}")
    return 0

# HD多线程_初始化操作回调
def operation_end_callback(index: int) -> int:
    """
    操作结束回调函数
    
    Args:
        index: 索引
    
    Returns:
        int: 返回值
    """
    print(f"End callback called with index: {index}")
    return 0

def pause_callback(index: int) -> int:
    """
    暂停回调函数
    
    Args:
        index: 索引
    
    Returns:
        int: 返回值
    """
    print(f"Pause callback called with index: {index}")
    return 0

def recover_callback(index: int) -> int:
    """
    恢复回调函数
    
    Args:
        index: 索引
    
    Returns:
        int: 返回值
    """
    print(f"Recover callback called with index: {index}")
    return 0

# HD中控_心跳操作回调
def heart_callback(windows: int, checkType: int) -> int:
    """
    心跳检查回调函数
    
    Args:
        windows: 窗口索引
        checkType: 检查类型
    
    Returns:
        int: 返回值
    """
    print(f"heart callback called with window index: {windows}, type: {checkType}")
    return 0

# HD安装_打开回调
# typedef __int64(__stdcall *UIFUNTYPE)(__int32 窗口序号);
def open_callback(winIndex: int) -> int:
    """
    打开进程回调函数
    
    Args:
        winIndex: 窗口索引
    
    Returns:
        int: 返回值
    """
    print(f"open_callBack winIndex: {winIndex}")
    return 0

# HD安装_检查回调
# typedef __int64(__stdcall *UIFUNTYPE)(int 窗口序号, int 之前窗口序号, int 之前进程PID, int 提示值);
def check_callback(winIndex: int, preWinIndex: int, prePid: int, error: int) -> int:
    """
    检查进程回调函数
    
    Args:
        winIndex: 窗口索引
        preWinIndex: 之前窗口索引
        prePid: 之前进程PID
        error: 错误提示值
    
    Returns:
        int: 返回值
    """
    print(f"check_callBack winIndex: {winIndex}, preWinIndex: {preWinIndex}, prePid: {prePid}, error: {error}")
    return 0

#####################################################
## stdcall回调类型
## stdcall回调类型





from .config import Config, ctypes
from .config import auto_encode

# INT64 __stdcall HCLUA_ReadFile(int winIndex, char* filePath, int luaID, BOOL exec, BOOL needRet, BOOL mainThread);
def HDLUA_读文件(窗口序号: int, 文件路径: str, LUA标识符: int, 是否执行: bool = False, 是否需要返回值: bool = False, 是否主线程: bool = False) -> str:
    """
    执行或加载LUA文件
    
    Args:
        窗口序号: 窗口索引（1到最大多开数）
        文件路径: LUA脚本完整路径
        LUA标识符: 线程标识符（0-100），当needRet=True时必须唯一
        是否执行: True=立即执行脚本并注入接口，False=仅注入接口不执行
        是否需要返回值: True=阻塞模式直到执行完成，False=异步执行
        是否主线程: True=在主线程上下文执行，False=后台线程执行
    
    Returns:
        str: JSON字符串，格式：{"error": 错误码, "ret": 执行结果, "data": 附加数据}
    """
    hd = Config.get_hd()
    
    HCLUA_ReadFile = hd.HCLUA_ReadFile
    HCLUA_ReadFile.restype = ctypes.c_char_p
    HCLUA_ReadFile.argtypes = [ctypes.c_int32, ctypes.c_char_p, ctypes.c_int32, ctypes.c_bool, ctypes.c_bool, ctypes.c_bool]
    
    ret = HCLUA_ReadFile(
        ctypes.c_int32(窗口序号),
        auto_encode(文件路径),
        ctypes.c_int32(LUA标识符),
        ctypes.c_bool(是否执行),
        ctypes.c_bool(是否需要返回值),
        ctypes.c_bool(是否主线程)
    )
    return ret.decode('utf-8') if ret else ""

# INT64 __stdcall HCLUA_CloseLua(int winIndex, int luaID);
def HDLUA_结束LUA(窗口序号: int, LUA标识符: int = -1) -> int:
    """
    终止LUA线程运行
    
    Args:
        窗口序号: 绑定的窗口索引
        LUA标识符: -1=终止所有线程，其他数值=终止指定标识符的线程
    
    Returns:
        int: 操作结果代码（负数表示失败）
    """
    hd = Config.get_hd()
    
    HCLUA_CloseLua = hd.HCLUA_CloseLua
    HCLUA_CloseLua.restype = ctypes.c_int64
    HCLUA_CloseLua.argtypes = [ctypes.c_int32, ctypes.c_int32]
    
    ret = HCLUA_CloseLua(ctypes.c_int32(窗口序号), ctypes.c_int32(LUA标识符))
    return ret

# INT64 __stdcall HCLUA_ExcuteCall(int winIndex, char* funcName, int argCount, INT64 rcx, INT64 rdx, INT64 r8, INT64 r9, INT64 l5, INT64 l6, BOOL mainThread);
def HDLUA_执行CALL(窗口序号: int, 函数名: str, 参数数量: int = 0, rcx: int = 0, rdx: int = 0, r8: int = 0, r9: int = 0, l5: int = 0, l6: int = 0, 是否主线程: bool = False) -> str:
    """
    调用已注册的LUA函数
    
    Args:
        窗口序号: 绑定的窗口索引
        函数名: 已注册的LUA函数名（大小写敏感）
        参数数量: 实际传递的参数个数（0-8）
        rcx: 第1个参数
        rdx: 第2个参数
        r8: 第3个参数
        r9: 第4个参数
        l5: 第5个参数
        l6: 第6个参数
        是否主线程: True=在主线程上下文执行
    
    Returns:
        str: JSON字符串，格式：{"error": 错误码, "ret": 执行结果, "data": 扩展数据}
    """
    hd = Config.get_hd()
    
    HCLUA_ExcuteCall = hd.HCLUA_ExcuteCall
    HCLUA_ExcuteCall.restype = ctypes.c_char_p
    HCLUA_ExcuteCall.argtypes = [ctypes.c_int32, ctypes.c_char_p, ctypes.c_int32, ctypes.c_int64, ctypes.c_int64, ctypes.c_int64, ctypes.c_int64, ctypes.c_int64, ctypes.c_int64, ctypes.c_bool]
    
    ret = HCLUA_ExcuteCall(
        ctypes.c_int32(窗口序号),
        auto_encode(函数名),
        ctypes.c_int32(参数数量),
        ctypes.c_int64(rcx),
        ctypes.c_int64(rdx),
        ctypes.c_int64(r8),
        ctypes.c_int64(r9),
        ctypes.c_int64(l5),
        ctypes.c_int64(l6),
        ctypes.c_bool(是否主线程)
    )
    return ret.decode('utf-8') if ret else ""



#软件找HD作者拿(魔改版)
from .config import Config, ctypes
from .config import auto_encode

# INT64 __stdcall HCIP_YMSetRootPath(char* path);
def HDIP_有米设置路径(路径: str) -> int:
    """
    设置有米软件路径（EXE路径）
    软件找HD作者拿（魔改版）
    
    Args:
        路径: 有米软件EXE路径
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCIP_YMSetRootPath = hd.HCIP_YMSetRootPath
    HCIP_YMSetRootPath.restype = ctypes.c_int64
    HCIP_YMSetRootPath.argtypes = [ctypes.c_char_p]
    
    ret = HCIP_YMSetRootPath(auto_encode(路径))
    return ret

# INT64 __stdcall HCIP_YMAddIP(char* ip, int port, char* account, char* password, int type, int kfp, char* proName);
def HDIP_有米添加IP(IP地址: str, 端口: int, 账号: str, 密码: str, 类型: int, 是否可分配: int = 1, 进程名: str = None) -> int:
    """
    添加有米IP代理设置
    软件找HD作者拿（魔改版）
    
    Args:
        IP地址: IP地址，如："127.0.0.1"
        端口: 端口号
        账号: 账号
        密码: 密码
        类型: 1表示socket，2表示ss
        是否可分配: 是否可分配（一般默认1）
        进程名: 进程名（一般为空即可）
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCIP_YMAddIP = hd.HCIP_YMAddIP
    HCIP_YMAddIP.restype = ctypes.c_int64
    HCIP_YMAddIP.argtypes = [ctypes.c_char_p, ctypes.c_int32, ctypes.c_char_p, ctypes.c_char_p, ctypes.c_int32, ctypes.c_int32, ctypes.c_char_p]
    
    if 进程名:
        pro_name = auto_encode(进程名)
    else:
        pro_name = None
    
    ret = HCIP_YMAddIP(
        auto_encode(IP地址),
        ctypes.c_int32(端口),
        auto_encode(账号),
        auto_encode(密码),
        ctypes.c_int32(类型),
        ctypes.c_int32(是否可分配),
        pro_name
    )
    return ret

# INT64 __stdcall HCIP_YMAddProcess(char* proName);
def HDIP_有米添加进程(进程名: str) -> int:
    """
    添加代理的进程名
    软件找HD作者拿（魔改版）
    
    Args:
        进程名: 进程名，如："Game.exe"
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCIP_YMAddProcess = hd.HCIP_YMAddProcess
    HCIP_YMAddProcess.restype = ctypes.c_int64
    HCIP_YMAddProcess.argtypes = [ctypes.c_char_p]
    
    ret = HCIP_YMAddProcess(auto_encode(进程名))
    return ret

# INT64 __stdcall HCIP_YMOpen(int type);
def HDIP_有米打开(类型: int) -> int:
    """
    打开有米软件
    软件找HD作者拿（魔改版）
    
    Args:
        类型: 类型（0国内IP，1国外IP）
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCIP_YMOpen = hd.HCIP_YMOpen
    HCIP_YMOpen.restype = ctypes.c_int64
    HCIP_YMOpen.argtypes = [ctypes.c_int32]
    
    ret = HCIP_YMOpen(ctypes.c_int32(类型))
    return ret

# INT64 __stdcall HCIP_YMIsOpen(int type);
def HDIP_有米是否打开(类型: int) -> int:
    """
    检查有米软件是否已经打开
    软件找HD作者拿（魔改版）
    
    Args:
        类型: 类型（0国内IP，1国外IP）
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCIP_YMIsOpen = hd.HCIP_YMIsOpen
    HCIP_YMIsOpen.restype = ctypes.c_int64
    HCIP_YMIsOpen.argtypes = [ctypes.c_int32]
    
    ret = HCIP_YMIsOpen(ctypes.c_int32(类型))
    return ret

# INT64 __stdcall HCIP_YMClose(int type);
def HDIP_有米关闭(类型: int) -> int:
    """
    关闭有米软件
    软件找HD作者拿（魔改版）
    
    Args:
        类型: 类型（0国内IP，1国外IP）
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCIP_YMClose = hd.HCIP_YMClose
    HCIP_YMClose.restype = ctypes.c_int64
    HCIP_YMClose.argtypes = [ctypes.c_int32]
    
    ret = HCIP_YMClose(ctypes.c_int32(类型))
    return ret


from .config import Config, ctypes
from .config import auto_encode

# HD打开回调
# typedef __int64(__stdcall *UIFUNTYPE)(__int32 windowsIndex);
HD_OpenFunType_stdcall = ctypes.WINFUNCTYPE(ctypes.c_int64, ctypes.c_int32)

# HD检查回调
# typedef __int64(__stdcall *CHECKINSTALLPLUGINTYPE)(int windowsIndex, int preWindowsIndex, int prePid, int error);
HD_CHFunType_stdcall = ctypes.WINFUNCTYPE(ctypes.c_int64, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32)

# INT64 __stdcall HDEX_InstallPlugin1(int winIndex, char* app, int appType, int injectType, int memType, int gameType, BOOL bAccept, INT64 openFun, INT64 checkFun, int timeOut);
def HD扩展_安装插件1(窗口序号: int, 进程名: str, 进程类型: int, 注入类型: int, 内存模式: int, 游戏类型: int, 是否开启接受线程: bool, 打开回调, 检查回调, 超时时间: int = 30000) -> int:
    """
    第一种通讯安装插件方式（安装插件后再打开进程）
    
    Args:
        窗口序号: 窗口序号
        进程名: 进程名
        进程类型: 进程类型 32/64
        注入类型: 注入类型 0 1 2
        内存模式: 内存模式 0 1 2
        游戏类型: 游戏类型，一般为0就行
        是否开启接受线程: 是否开启接受线程
        打开回调: 回调类型查看INSTALLPLUGINTYPE
        检查回调: 检查回调类型查看，默认NULL
        超时时间: 超时时间
    
    Returns:
        int: 返回值代码
    """
    hd = Config.get_hd()
    
    HDEX_InstallPlugin1 = hd.HDEX_InstallPlugin1
    HDEX_InstallPlugin1.restype = ctypes.c_int64
    HDEX_InstallPlugin1.argtypes = [
        ctypes.c_int32,
        ctypes.c_char_p,
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_int64,
        ctypes.c_int64,
        ctypes.c_int32
    ]
    
    打开回调Fun = HD_OpenFunType_stdcall(打开回调) if 打开回调 else None
    检查回调Fun = HD_CHFunType_stdcall(检查回调) if 检查回调 else None
    
    open_fun_ptr = ctypes.c_int64(ctypes.cast(打开回调Fun, ctypes.c_void_p).value) if 打开回调Fun else ctypes.c_int64(0)
    check_fun_ptr = ctypes.c_int64(ctypes.cast(检查回调Fun, ctypes.c_void_p).value) if 检查回调Fun else ctypes.c_int64(0)
    
    ret = HDEX_InstallPlugin1(
        ctypes.c_int32(窗口序号),
        auto_encode(进程名),
        ctypes.c_int32(进程类型),
        ctypes.c_int32(注入类型),
        ctypes.c_int32(内存模式),
        ctypes.c_int32(游戏类型),
        ctypes.c_int32(是否开启接受线程),
        open_fun_ptr,
        check_fun_ptr,
        ctypes.c_int32(超时时间)
    )
    return ret

# INT64 __stdcall HDEX_InstallPlugin2(int winIndex, int funType, int pid, int appType, int gameType, BOOL bAccept, INT64 openFun, INT64 checkFun, int timeOut);
def HD扩展_安装插件2(窗口序号: int, 接口类型: int, 指定PID: int, 进程类型: int, 游戏类型: int, 是否开启接受线程: bool, 打开回调, 检查回调, 超时时间: int = 30000) -> int:
    """
    第二种通讯安装插件方式（打开进程后安装插件），通过pid
    
    Args:
        窗口序号: 窗口序号
        接口类型: 安装插件接口类型表 支持2 4 6
        指定PID: 指定PID，可以为0
        进程类型: 进程类型 32/64
        游戏类型: 游戏类型，一般为0就行
        是否开启接受线程: 是否开启接受线程
        打开回调: 回调类型查看，可选，默认NULL
        检查回调: 检查回调类型查看，可选，默认NULL
        超时时间: 超时时间
    
    Returns:
        int: 返回值代码
    """
    hd = Config.get_hd()
    
    HDEX_InstallPlugin2 = hd.HDEX_InstallPlugin2
    HDEX_InstallPlugin2.restype = ctypes.c_int64
    HDEX_InstallPlugin2.argtypes = [
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_int64,
        ctypes.c_int64,
        ctypes.c_int32
    ]
    
    打开回调Fun = HD_OpenFunType_stdcall(打开回调) if 打开回调 else None
    检查回调Fun = HD_CHFunType_stdcall(检查回调) if 检查回调 else None
    
    open_fun_ptr = ctypes.c_int64(ctypes.cast(打开回调Fun, ctypes.c_void_p).value) if 打开回调Fun else ctypes.c_int64(0)
    check_fun_ptr = ctypes.c_int64(ctypes.cast(检查回调Fun, ctypes.c_void_p).value) if 检查回调Fun else ctypes.c_int64(0)
    
    ret = HDEX_InstallPlugin2(
        ctypes.c_int32(窗口序号),
        ctypes.c_int32(接口类型),
        ctypes.c_int32(指定PID),
        ctypes.c_int32(进程类型),
        ctypes.c_int32(游戏类型),
        ctypes.c_int32(是否开启接受线程),
        open_fun_ptr,
        check_fun_ptr,
        ctypes.c_int32(超时时间)
    )
    return ret

# INT64 __stdcall HDEX_InstallPlugin3(int winIndex, int funType, INT64 hwnd, int appType, int gameType, BOOL bAccept, INT64 openFun, INT64 checkFun, int timeOut);
def HD扩展_安装插件3(窗口序号: int, 接口类型: int, 指定窗口句柄: int, 进程类型: int, 游戏类型: int, 是否开启接受线程: bool, 打开回调, 检查回调, 超时时间: int = 30000) -> int:
    """
    第二种通讯安装插件方式（打开进程后安装插件），通过窗口句柄
    
    Args:
        窗口序号: 窗口序号
        接口类型: 安装插件接口类型表 支持3 5 7
        指定窗口句柄: 指定窗口句柄，可以为0
        进程类型: 进程类型 32/64
        游戏类型: 游戏类型，一般为0就行
        是否开启接受线程: 是否开启接受线程
        打开回调: 回调类型查看，可选，默认NULL
        检查回调: 检查回调类型查看，可选，默认NULL
        超时时间: 超时时间
    
    Returns:
        int: 返回值代码
    """
    hd = Config.get_hd()
    
    HDEX_InstallPlugin3 = hd.HDEX_InstallPlugin3
    HDEX_InstallPlugin3.restype = ctypes.c_int64
    HDEX_InstallPlugin3.argtypes = [
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_int64,
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_int64,
        ctypes.c_int64,
        ctypes.c_int32
    ]
    
    打开回调Fun = HD_OpenFunType_stdcall(打开回调) if 打开回调 else None
    检查回调Fun = HD_CHFunType_stdcall(检查回调) if 检查回调 else None
    
    open_fun_ptr = ctypes.c_int64(ctypes.cast(打开回调Fun, ctypes.c_void_p).value) if 打开回调Fun else ctypes.c_int64(0)
    check_fun_ptr = ctypes.c_int64(ctypes.cast(检查回调Fun, ctypes.c_void_p).value) if 检查回调Fun else ctypes.c_int64(0)
    
    ret = HDEX_InstallPlugin3(
        ctypes.c_int32(窗口序号),
        ctypes.c_int32(接口类型),
        ctypes.c_int64(指定窗口句柄),
        ctypes.c_int32(进程类型),
        ctypes.c_int32(游戏类型),
        ctypes.c_int32(是否开启接受线程),
        open_fun_ptr,
        check_fun_ptr,
        ctypes.c_int32(超时时间)
    )
    return ret

# INT64 __stdcall HDEX_InstallPluginVM(int winIndex, int funType, int vmPid, int vncPort, int appType, INT64 openFun, INT64 checkFun, int timeOut);
def HD扩展_安装插件VM(窗口序号: int, 接口类型: int, 虚拟机PID: int, VNC端口: int, 进程类型: int, 打开回调=None, 检查回调=None, 超时时间: int = 30000) -> int:
    """
    安装插件VM版本，通过PID针对虚拟机内部自动关联虚拟机
    
    Args:
        窗口序号: 窗口序号
        接口类型: 内部安装插件接口类型，查看安装插件接口类型表 支持3 5 7
        虚拟机PID: 虚拟机PID，或者打开回调指定
        VNC端口: 虚拟机VNC端口，-1表示不连接VNC，大于0表示连接VNC（会断开后重新连接），0为使用之前的缓存VNC端口（会断开后重新连接）
        进程类型: 进程类型 32/64
        打开回调: 打开回调
        检查回调: 检查回调
        超时时间: 超时时间
    
    Returns:
        int: 返回值代码
    
    Note:
        1.调用之前记得打开服务器HCVMDMA_StartServer并确定正确打开HCVMDMA_ServerIsStart
        2.其他规则和前3种安装插件方式一致
        3.支持重连，重连的前提是不能被HCEnv_UnLoad卸载
        4.如果使用HD多线程模块 强烈建议在登录回调中使用
    """
    hd = Config.get_hd()
    
    HDEX_InstallPluginVM = hd.HDEX_InstallPluginVM
    HDEX_InstallPluginVM.restype = ctypes.c_int64
    HDEX_InstallPluginVM.argtypes = [
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_int64,
        ctypes.c_int64,
        ctypes.c_int32
    ]
    
    openFun_ptr = ctypes.c_int64(ctypes.cast(HD_OpenFunType_stdcall(打开回调), ctypes.c_void_p).value) if 打开回调 else ctypes.c_int64(0)
    checkFun_ptr = ctypes.c_int64(ctypes.cast(HD_CHFunType_stdcall(检查回调), ctypes.c_void_p).value) if 检查回调 else ctypes.c_int64(0)
    
    ret = HDEX_InstallPluginVM(
        ctypes.c_int32(窗口序号),
        ctypes.c_int32(接口类型),
        ctypes.c_int32(虚拟机PID),
        ctypes.c_int32(VNC端口),
        ctypes.c_int32(进程类型),
        openFun_ptr,
        checkFun_ptr,
        ctypes.c_int32(超时时间)
    )
    return ret


from .config import Config, ctypes
from .config import auto_encode

# INT64 __stdcall HCVnc_Connect(int windowIndex, int port);
def HDVNC_连接虚拟机(窗口序号: int, 端口: int) -> int:
    """
    连接虚拟机VNC服务
    
    Args:
        窗口序号: 窗口序号，每个窗口序号可以绑定一个虚拟机VNC端口，指定0表示重连
        端口: 虚拟机开启VNC设置的端口
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCVnc_Connect = hd.HCVnc_Connect
    HCVnc_Connect.restype = ctypes.c_int64
    HCVnc_Connect.argtypes = [ctypes.c_int32, ctypes.c_int32]
    
    ret = HCVnc_Connect(ctypes.c_int32(窗口序号), ctypes.c_int32(端口))
    return ret

# INT64 __stdcall HCVnc_Close(int windowIndex);
def HDVNC_关闭连接(窗口序号: int) -> int:
    """
    关闭VNC虚拟机连接
    
    Args:
        窗口序号: 窗口序号，每个窗口序号可以绑定一个虚拟机VNC端口
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCVnc_Close = hd.HCVnc_Close
    HCVnc_Close.restype = ctypes.c_int64
    HCVnc_Close.argtypes = [ctypes.c_int32]
    
    ret = HCVnc_Close(ctypes.c_int32(窗口序号))
    return ret

# INT64 __stdcall HCVnc_MoveTo(int windowIndex, int x, int y);
def HDVNC_鼠标绝对移动(窗口序号: int, X坐标: int, Y坐标: int) -> int:
    """
    VNC鼠标绝对移动（自带移动轨迹，直线波动防检测）
    
    Args:
        窗口序号: 窗口序号，每个窗口序号可以绑定一个虚拟机VNC端口
        X坐标: 虚拟机屏幕坐标X
        Y坐标: 虚拟机屏幕坐标Y
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCVnc_MoveTo = hd.HCVnc_MoveTo
    HCVnc_MoveTo.restype = ctypes.c_int64
    HCVnc_MoveTo.argtypes = [ctypes.c_int32, ctypes.c_int32, ctypes.c_int32]
    
    ret = HCVnc_MoveTo(ctypes.c_int32(窗口序号), ctypes.c_int32(X坐标), ctypes.c_int32(Y坐标))
    return ret

# INT64 __stdcall HCVnc_MoveToOffset(int windowIndex, int x, int y);
def HDVNC_鼠标相对移动(窗口序号: int, X偏移: int, Y偏移: int) -> int:
    """
    VNC鼠标相对移动（自带移动轨迹，直线波动防检测）
    
    Args:
        窗口序号: 窗口序号，每个窗口序号可以绑定一个虚拟机VNC端口
        X偏移: 虚拟机屏幕相对坐标X
        Y偏移: 虚拟机屏幕相对坐标Y
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCVnc_MoveToOffset = hd.HCVnc_MoveToOffset
    HCVnc_MoveToOffset.restype = ctypes.c_int64
    HCVnc_MoveToOffset.argtypes = [ctypes.c_int32, ctypes.c_int32, ctypes.c_int32]
    
    ret = HCVnc_MoveToOffset(ctypes.c_int32(窗口序号), ctypes.c_int32(X偏移), ctypes.c_int32(Y偏移))
    return ret

# INT64 __stdcall HCVnc_LeftDown(int windowIndex);
def HDVNC_鼠标左键按下(窗口序号: int) -> int:
    """
    VNC鼠标左键按下
    
    Args:
        窗口序号: 窗口序号，每个窗口序号可以绑定一个虚拟机VNC端口
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCVnc_LeftDown = hd.HCVnc_LeftDown
    HCVnc_LeftDown.restype = ctypes.c_int64
    HCVnc_LeftDown.argtypes = [ctypes.c_int32]
    
    ret = HCVnc_LeftDown(ctypes.c_int32(窗口序号))
    return ret

# INT64 __stdcall HCVnc_LeftUp(int windowIndex);
def HDVNC_鼠标左键弹起(窗口序号: int) -> int:
    """
    VNC鼠标左键弹起
    
    Args:
        窗口序号: 窗口序号，每个窗口序号可以绑定一个虚拟机VNC端口
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCVnc_LeftUp = hd.HCVnc_LeftUp
    HCVnc_LeftUp.restype = ctypes.c_int64
    HCVnc_LeftUp.argtypes = [ctypes.c_int32]
    
    ret = HCVnc_LeftUp(ctypes.c_int32(窗口序号))
    return ret

# INT64 __stdcall HCVnc_LeftDoubleClick(int windowIndex);
def HDVNC_鼠标左键双击(窗口序号: int) -> int:
    """
    VNC鼠标左键双击
    
    Args:
        窗口序号: 窗口序号，每个窗口序号可以绑定一个虚拟机VNC端口
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCVnc_LeftDoubleClick = hd.HCVnc_LeftDoubleClick
    HCVnc_LeftDoubleClick.restype = ctypes.c_int64
    HCVnc_LeftDoubleClick.argtypes = [ctypes.c_int32]
    
    ret = HCVnc_LeftDoubleClick(ctypes.c_int32(窗口序号))
    return ret

# INT64 __stdcall HCVnc_LeftClick(int windowIndex);
def HDVNC_鼠标左键点击(窗口序号: int) -> int:
    """
    VNC鼠标左键点击
    
    Args:
        窗口序号: 窗口序号，每个窗口序号可以绑定一个虚拟机VNC端口
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCVnc_LeftClick = hd.HCVnc_LeftClick
    HCVnc_LeftClick.restype = ctypes.c_int64
    HCVnc_LeftClick.argtypes = [ctypes.c_int32]
    
    ret = HCVnc_LeftClick(ctypes.c_int32(窗口序号))
    return ret

# INT64 __stdcall HCVnc_RightClick(int windowIndex);
def HDVNC_鼠标右键点击(窗口序号: int) -> int:
    """
    VNC鼠标右键点击
    
    Args:
        窗口序号: 窗口序号，每个窗口序号可以绑定一个虚拟机VNC端口
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCVnc_RightClick = hd.HCVnc_RightClick
    HCVnc_RightClick.restype = ctypes.c_int64
    HCVnc_RightClick.argtypes = [ctypes.c_int32]
    
    ret = HCVnc_RightClick(ctypes.c_int32(窗口序号))
    return ret

# INT64 __stdcall HCVnc_RightDown(int windowIndex);
def HDVNC_鼠标右键按下(窗口序号: int) -> int:
    """
    VNC鼠标右键按下
    
    Args:
        窗口序号: 窗口序号，每个窗口序号可以绑定一个虚拟机VNC端口
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCVnc_RightDown = hd.HCVnc_RightDown
    HCVnc_RightDown.restype = ctypes.c_int64
    HCVnc_RightDown.argtypes = [ctypes.c_int32]
    
    ret = HCVnc_RightDown(ctypes.c_int32(窗口序号))
    return ret

# INT64 __stdcall HCVnc_RightUp(int windowIndex);
def HDVNC_鼠标右键弹起(窗口序号: int) -> int:
    """
    VNC鼠标右键弹起
    
    Args:
        窗口序号: 窗口序号，每个窗口序号可以绑定一个虚拟机VNC端口
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCVnc_RightUp = hd.HCVnc_RightUp
    HCVnc_RightUp.restype = ctypes.c_int64
    HCVnc_RightUp.argtypes = [ctypes.c_int32]
    
    ret = HCVnc_RightUp(ctypes.c_int32(窗口序号))
    return ret

# INT64 __stdcall HCVnc_WheelDown(int windowIndex);
def HDVNC_鼠标滚轮滚下(窗口序号: int) -> int:
    """
    VNC鼠标滚轮向下滚动
    
    Args:
        窗口序号: 窗口序号，每个窗口序号可以绑定一个虚拟机VNC端口
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCVnc_WheelDown = hd.HCVnc_WheelDown
    HCVnc_WheelDown.restype = ctypes.c_int64
    HCVnc_WheelDown.argtypes = [ctypes.c_int32]
    
    ret = HCVnc_WheelDown(ctypes.c_int32(窗口序号))
    return ret

# INT64 __stdcall HCVnc_WheelUp(int windowIndex);
def HDVNC_鼠标滚轮滚上(窗口序号: int) -> int:
    """
    VNC鼠标滚轮向上滚动
    
    Args:
        窗口序号: 窗口序号，每个窗口序号可以绑定一个虚拟机VNC端口
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCVnc_WheelUp = hd.HCVnc_WheelUp
    HCVnc_WheelUp.restype = ctypes.c_int64
    HCVnc_WheelUp.argtypes = [ctypes.c_int32]
    
    ret = HCVnc_WheelUp(ctypes.c_int32(窗口序号))
    return ret

# INT64 __stdcall HCVnc_KeyTap(int windowIndex, int keycode, BOOL isKeypad);
def HDVNC_键盘按键敲击(窗口序号: int, 键码: int, 是否小键盘: bool = False) -> int:
    """
    VNC键盘按键敲击（按下+弹起）
    
    Args:
        窗口序号: 窗口序号，每个窗口序号可以绑定一个虚拟机VNC端口
        键码: 键盘按键码
        是否小键盘: 是否为小键盘按键，默认False
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCVnc_KeyTap = hd.HCVnc_KeyTap
    HCVnc_KeyTap.restype = ctypes.c_int64
    HCVnc_KeyTap.argtypes = [ctypes.c_int32, ctypes.c_int32, ctypes.c_bool]
    
    ret = HCVnc_KeyTap(ctypes.c_int32(窗口序号), ctypes.c_int32(键码), ctypes.c_bool(是否小键盘))
    return ret

# INT64 __stdcall HCVnc_KeyDown(int windowIndex, int keycode);
def HDVNC_键盘按键按下(窗口序号: int, 键码: int) -> int:
    """
    VNC键盘按键按下
    
    Args:
        窗口序号: 窗口序号，每个窗口序号可以绑定一个虚拟机VNC端口
        键码: 键盘按键码
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCVnc_KeyDown = hd.HCVnc_KeyDown
    HCVnc_KeyDown.restype = ctypes.c_int64
    HCVnc_KeyDown.argtypes = [ctypes.c_int32, ctypes.c_int32]
    
    ret = HCVnc_KeyDown(ctypes.c_int32(窗口序号), ctypes.c_int32(键码))
    return ret

# INT64 __stdcall HCVnc_KeyUp(int windowIndex, int keycode);
def HDVNC_键盘按键弹起(窗口序号: int, 键码: int) -> int:
    """
    VNC键盘按键弹起
    
    Args:
        窗口序号: 窗口序号，每个窗口序号可以绑定一个虚拟机VNC端口
        键码: 键盘按键码
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCVnc_KeyUp = hd.HCVnc_KeyUp
    HCVnc_KeyUp.restype = ctypes.c_int64
    HCVnc_KeyUp.argtypes = [ctypes.c_int32, ctypes.c_int32]
    
    ret = HCVnc_KeyUp(ctypes.c_int32(窗口序号), ctypes.c_int32(键码))
    return ret

# INT64 __stdcall HCVnc_KeysString(int windowIndex, char* strText, BOOL isKeypad);
def HDVNC_键盘连续按键字符串(窗口序号: int, 文本内容: str, 是否小键盘: bool = False) -> int:
    """
    VNC键盘连续按键字符串（只支持英文字符串）
    
    Args:
        窗口序号: 窗口序号，每个窗口序号可以绑定一个虚拟机VNC端口
        文本内容: 要输入的字符串（只支持英文）
        是否小键盘: 是否为小键盘按键，默认False
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCVnc_KeysString = hd.HCVnc_KeysString
    HCVnc_KeysString.restype = ctypes.c_int64
    HCVnc_KeysString.argtypes = [ctypes.c_int32, ctypes.c_char_p, ctypes.c_bool]
    
    ret = HCVnc_KeysString(ctypes.c_int32(窗口序号), auto_encode(文本内容), ctypes.c_bool(是否小键盘))
    return ret

# INT64 __stdcall HCVnc_InputString(int windowIndex, char* strText);
def HDVNC_键盘输入字符串(窗口序号: int, 文本内容: str) -> int:
    """
    VNC键盘输入字符串（支持中文）
    
    Args:
        窗口序号: 窗口序号，每个窗口序号可以绑定一个虚拟机VNC端口
        文本内容: 要输入的字符串（支持中文）
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCVnc_InputString = hd.HCVnc_InputString
    HCVnc_InputString.restype = ctypes.c_int64
    HCVnc_InputString.argtypes = [ctypes.c_int32, ctypes.c_char_p]
    
    ret = HCVnc_InputString(ctypes.c_int32(窗口序号), auto_encode(文本内容))
    return ret

# INT64 __stdcall HCVnc_OpenCapture(int windowIndex);
def HDVNC_开启截图(窗口序号: int) -> int:
    """
    开启VNC截图功能
    
    Args:
        窗口序号: 窗口序号，每个窗口序号可以绑定一个虚拟机VNC端口
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCVnc_OpenCapture = hd.HCVnc_OpenCapture
    HCVnc_OpenCapture.restype = ctypes.c_int64
    HCVnc_OpenCapture.argtypes = [ctypes.c_int32]
    
    ret = HCVnc_OpenCapture(ctypes.c_int32(窗口序号))
    return ret

# INT64 __stdcall HCVnc_CloseCapture(int windowIndex);
def HDVNC_关闭截图(窗口序号: int) -> int:
    """
    关闭VNC截图功能
    
    Args:
        窗口序号: 窗口序号，每个窗口序号可以绑定一个虚拟机VNC端口
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCVnc_CloseCapture = hd.HCVnc_CloseCapture
    HCVnc_CloseCapture.restype = ctypes.c_int64
    HCVnc_CloseCapture.argtypes = [ctypes.c_int32]
    
    ret = HCVnc_CloseCapture(ctypes.c_int32(窗口序号))
    return ret



from .config import Config, ctypes
from .config import auto_encode

# INT64 __stdcall HCSYS_CheckFontSmooth();
def HD系统_是否开启字体平滑() -> int:
    """
    检查字体是否开启字体平滑
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCSYS_CheckFontSmooth = hd.HCSYS_CheckFontSmooth
    HCSYS_CheckFontSmooth.restype = ctypes.c_int64
    HCSYS_CheckFontSmooth.argtypes = []
    
    ret = HCSYS_CheckFontSmooth()
    return ret

# INT64 __stdcall HCSYS_CloseFontSmooth();
def HD系统_关闭字体平滑() -> int:
    """
    关闭字体平滑
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCSYS_CloseFontSmooth = hd.HCSYS_CloseFontSmooth
    HCSYS_CloseFontSmooth.restype = ctypes.c_int64
    HCSYS_CloseFontSmooth.argtypes = []
    
    ret = HCSYS_CloseFontSmooth()
    return ret

# INT64 __stdcall HCSYS_OpenFontSmooth();
def HD系统_打开字体平滑() -> int:
    """
    打开字体平滑
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCSYS_OpenFontSmooth = hd.HCSYS_OpenFontSmooth
    HCSYS_OpenFontSmooth.restype = ctypes.c_int64
    HCSYS_OpenFontSmooth.argtypes = []
    
    ret = HCSYS_OpenFontSmooth()
    return ret

# INT64 __stdcall HCSYS_CheckUAC();
def HD系统_是否开启UAC() -> int:
    """
    检查当前系统是否开启了UAC（用户控制）
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCSYS_CheckUAC = hd.HCSYS_CheckUAC
    HCSYS_CheckUAC.restype = ctypes.c_int64
    HCSYS_CheckUAC.argtypes = []
    
    ret = HCSYS_CheckUAC()
    return ret

# INT64 __stdcall HCSYS_SetUAC(int bEnable);
def HD系统_设置UAC(是否开启: int) -> int:
    """
    设置当前系统的UAC（用户控制）开关
    
    Args:
        是否开启: 是否开启UAC（0: 关闭, 1: 开启）
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCSYS_SetUAC = hd.HCSYS_SetUAC
    HCSYS_SetUAC.restype = ctypes.c_int64
    HCSYS_SetUAC.argtypes = [ctypes.c_int32]
    
    ret = HCSYS_SetUAC(ctypes.c_int32(是否开启))
    return ret

# INT64 __stdcall HCSYS_Delay(int 毫秒);
def HD系统_延迟(毫秒: int) -> int:
    """
    延迟，不会堵塞主线程
    
    Args:
        毫秒: 毫秒数
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCSYS_Delay = hd.HCSYS_Delay
    HCSYS_Delay.restype = ctypes.c_int64
    HCSYS_Delay.argtypes = [ctypes.c_int32]
    
    ret = HCSYS_Delay(ctypes.c_int32(毫秒))
    return ret

# INT64 __stdcall HCSYS_DelayEx(int 最小毫秒, int 最大毫秒);
def HD系统_随机延迟(最小毫秒: int, 最大毫秒: int) -> int:
    """
    在随机范围内延迟，不会堵塞主线程
    
    Args:
        最小毫秒: 最小延迟时间
        最大毫秒: 最大延迟时间
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCSYS_DelayEx = hd.HCSYS_DelayEx
    HCSYS_DelayEx.restype = ctypes.c_int64
    HCSYS_DelayEx.argtypes = [ctypes.c_int32, ctypes.c_int32]
    
    ret = HCSYS_DelayEx(ctypes.c_int32(最小毫秒), ctypes.c_int32(最大毫秒))
    return ret

# INT64 __stdcall HCSYS_ExitSys(int type);
def HD系统_关闭系统(类型: int) -> int:
    """
    关闭系统
    
    Args:
        类型: 注销(0), 关机(1), 重启(2)
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCSYS_ExitSys = hd.HCSYS_ExitSys
    HCSYS_ExitSys.restype = ctypes.c_int64
    HCSYS_ExitSys.argtypes = [ctypes.c_int32]
    
    ret = HCSYS_ExitSys(ctypes.c_int32(类型))
    return ret

# INT64 __stdcall HCSYS_CloseScreenProtect();
def HD系统_关闭屏保() -> int:
    """
    关闭屏保
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCSYS_CloseScreenProtect = hd.HCSYS_CloseScreenProtect
    HCSYS_CloseScreenProtect.restype = ctypes.c_int64
    HCSYS_CloseScreenProtect.argtypes = []
    
    ret = HCSYS_CloseScreenProtect()
    return ret

# INT64 __stdcall HCSYS_ClosePowerManager();
def HD系统_关闭电源管理() -> int:
    """
    关闭电源管理，不进入睡眠
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCSYS_ClosePowerManager = hd.HCSYS_ClosePowerManager
    HCSYS_ClosePowerManager.restype = ctypes.c_int64
    HCSYS_ClosePowerManager.argtypes = []
    
    ret = HCSYS_ClosePowerManager()
    return ret

# INT64 __stdcall HCSYS_ResumeSystemModify();
def HD系统_恢复最近系统修改() -> int:
    """
    恢复系统上次的修改
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCSYS_ResumeSystemModify = hd.HCSYS_ResumeSystemModify
    HCSYS_ResumeSystemModify.restype = ctypes.c_int64
    HCSYS_ResumeSystemModify.argtypes = []
    
    ret = HCSYS_ResumeSystemModify()
    return ret

# INT64 __stdcall HCSYS_DisableCloseDisplayAndSleep();
def HD系统_禁止休眠() -> int:
    """
    设置当前的电源设置（禁止关闭显示器，禁止关闭硬盘，禁止睡眠和待机）
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCSYS_DisableCloseDisplayAndSleep = hd.HCSYS_DisableCloseDisplayAndSleep
    HCSYS_DisableCloseDisplayAndSleep.restype = ctypes.c_int64
    HCSYS_DisableCloseDisplayAndSleep.argtypes = []
    
    ret = HCSYS_DisableCloseDisplayAndSleep()
    return ret

# INT64 __stdcall HCSYS_GetDir(int type);
def HD系统_获取路径(类型: int) -> int:
    """
    获取路径并返回json字符串
    
    Args:
        类型: 当前路径(0), system32路径(1), windows所在路径(2), 临时目录路径(3), 当前进程(exe)所在的路径(4)
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCSYS_GetDir = hd.HCSYS_GetDir
    HCSYS_GetDir.restype = ctypes.c_int64
    HCSYS_GetDir.argtypes = [ctypes.c_int32]
    
    ret = HCSYS_GetDir(ctypes.c_int32(类型))
    return ret

# INT64 __stdcall HCSYS_GetCpuType();
def HD系统_获取CPU类型() -> int:
    """
    获取CPU类型
    
    Returns:
        int: 返回值代码（查看HD返回值表）
            1: Intel
            2: AMD
    """
    hd = Config.get_hd()
    
    HCSYS_GetCpuType = hd.HCSYS_GetCpuType
    HCSYS_GetCpuType.restype = ctypes.c_int64
    HCSYS_GetCpuType.argtypes = []
    
    ret = HCSYS_GetCpuType()
    return ret

# INT64 __stdcall HCSYS_GetCpuUsage();
def HD系统_获取当前CPU使用率() -> int:
    """
    获取CPU使用率
    
    Returns:
        int: 返回值代码（查看HD返回值表）
            大于0表示: 使用率百分比
    """
    hd = Config.get_hd()
    
    HCSYS_GetCpuUsage = hd.HCSYS_GetCpuUsage
    HCSYS_GetCpuUsage.restype = ctypes.c_int64
    HCSYS_GetCpuUsage.argtypes = []
    
    ret = HCSYS_GetCpuUsage()
    return ret

# INT64 __stdcall HCSYS_GetCpuUsageByPid(int pid);
def HD系统_获取CPU使用率(进程PID: int) -> int:
    """
    获取指定进程的CPU使用率
    
    Args:
        进程PID: 进程PID
    
    Returns:
        int: 返回值代码（查看HD返回值表）
            大于0表示: 使用率百分比
    """
    hd = Config.get_hd()
    
    HCSYS_GetCpuUsageByPid = hd.HCSYS_GetCpuUsageByPid
    HCSYS_GetCpuUsageByPid.restype = ctypes.c_int64
    HCSYS_GetCpuUsageByPid.argtypes = [ctypes.c_int32]
    
    ret = HCSYS_GetCpuUsageByPid(ctypes.c_int32(进程PID))
    return ret

# INT64 __stdcall HCSYS_GetMemoryUsageByPid(int pid);
def HD系统_获取内存使用率(进程PID: int) -> int:
    """
    获取指定进程的内存使用率
    
    Args:
        进程PID: 进程PID
    
    Returns:
        int: 返回值代码（查看HD返回值表）
            大于0表示: 使用率百分比
    """
    hd = Config.get_hd()
    
    HCSYS_GetMemoryUsageByPid = hd.HCSYS_GetMemoryUsageByPid
    HCSYS_GetMemoryUsageByPid.restype = ctypes.c_int64
    HCSYS_GetMemoryUsageByPid.argtypes = [ctypes.c_int32]
    
    ret = HCSYS_GetMemoryUsageByPid(ctypes.c_int32(进程PID))
    return ret

# INT64 __stdcall HCSYS_GetDiskSerial(int index);
def HD系统_获取磁盘序列号(磁盘序号: int) -> int:
    """
    获取磁盘序列号
    
    Args:
        磁盘序号: 磁盘序号
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCSYS_GetDiskSerial = hd.HCSYS_GetDiskSerial
    HCSYS_GetDiskSerial.restype = ctypes.c_int64
    HCSYS_GetDiskSerial.argtypes = [ctypes.c_int32]
    
    ret = HCSYS_GetDiskSerial(ctypes.c_int32(磁盘序号))
    return ret

# INT64 __stdcall HCSYS_GetDisplayInfo();
def HD系统_获取显卡信息() -> int:
    """
    获取显卡信息
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCSYS_GetDisplayInfo = hd.HCSYS_GetDisplayInfo
    HCSYS_GetDisplayInfo.restype = ctypes.c_int64
    HCSYS_GetDisplayInfo.argtypes = []
    
    ret = HCSYS_GetDisplayInfo()
    return ret

# INT64 __stdcall HCSYS_GetDPI();
def HD系统_获取DPI() -> int:
    """
    获取DPI
    
    Returns:
        int: 返回值代码（查看HD返回值表）
            大于0表示: 具体的DPI
    """
    hd = Config.get_hd()
    
    HCSYS_GetDPI = hd.HCSYS_GetDPI
    HCSYS_GetDPI.restype = ctypes.c_int64
    HCSYS_GetDPI.argtypes = []
    
    ret = HCSYS_GetDPI()
    return ret

# INT64 __stdcall HCSYS_RunApp(char* path, long type);
def HD系统_启动EXE(exe路径: str, 返回值类型: int) -> int:
    """
    运行指定路径下的exe
    
    Args:
        exe路径: exe路径
        返回值类型: 返回值类型（进程ID(0), 线程ID(1), 进程句柄(2), 线程句柄(3)）
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCSYS_RunApp = hd.HCSYS_RunApp
    HCSYS_RunApp.restype = ctypes.c_int64
    HCSYS_RunApp.argtypes = [ctypes.c_char_p, ctypes.c_long]
    
    ret = HCSYS_RunApp(auto_encode(exe路径), ctypes.c_long(返回值类型))
    return ret

# INT64 __stdcall HCSYS_RunAppGetRet(char* cmdApp, BOOL bShowCrol, BOOL bWait);
def HD系统_执行DOS指令取返回(命令应用: str, 是否显示控制台: bool, 是否等待进程结束返回: bool) -> int:
    """
    获取CMD命令形式的打开进程并获取返回输出
    
    Args:
        命令应用: 带exe+启动参数
        是否显示控制台: 是否显示进程窗口
        是否等待进程结束返回: 是否等待进程结束返回（True: 等待，False: 不等待）
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCSYS_RunAppGetRet = hd.HCSYS_RunAppGetRet
    HCSYS_RunAppGetRet.restype = ctypes.c_int64
    HCSYS_RunAppGetRet.argtypes = [ctypes.c_char_p, ctypes.c_bool, ctypes.c_bool]
    
    ret = HCSYS_RunAppGetRet(
        auto_encode(命令应用),
        ctypes.c_bool(是否显示控制台),
        ctypes.c_bool(是否等待进程结束返回)
    )
    return ret

# INT64 __stdcall HCSYS_RunAppGetRetEx(char* cmdApp, char* lparam, BOOL bAs);
def HD系统_管理员打开进程(命令应用: str, 启动参数: str, 是否管理员: bool = True) -> int:
    """
    获取CMD命令形式的打开进程（支持管理员打开）（扩展版本）
    
    Args:
        命令应用: APP路径+APP，如: J:\\HMADG\\HMad\\x64\\Release\\GoogleAuthy.exe
        启动参数: 启动参数，如: DN7BNCWGVYBJHC677AYLLC3EFZEU2VIP
        是否管理员: 是否管理员
    
    Returns:
        int: 成功返回PID和返回json，失败返回查看返回值表HD返回值表
    
    Note:
        内部是调用ShellExecuteExA
    """
    hd = Config.get_hd()
    
    HCSYS_RunAppGetRetEx = hd.HCSYS_RunAppGetRetEx
    HCSYS_RunAppGetRetEx.restype = ctypes.c_int64
    HCSYS_RunAppGetRetEx.argtypes = [ctypes.c_char_p, ctypes.c_char_p, ctypes.c_bool]
    
    ret = HCSYS_RunAppGetRetEx(
        auto_encode(命令应用),
        auto_encode(启动参数),
        ctypes.c_bool(是否管理员)
    )
    return ret

# INT64 __stdcall HCSYS_RunAppEx(char* path, char* appName, char* lparam, int flag, long type);
def HD系统_启动EXE带参数(路径: str, 应用名: str, 启动参数: str, 标志: int, 返回值类型: int) -> int:
    """
    运行指定路径下的exe，支持启动参数
    
    Args:
        路径: exe路径
        应用名: exe名字
        启动参数: 启动参数
        标志: 启动标志（挂起状态打开(4), 直接打开运行(0)）
        返回值类型: 返回值类型（进程ID(0), 线程ID(1), 进程句柄(2), 线程句柄(3)）
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCSYS_RunAppEx = hd.HCSYS_RunAppEx
    HCSYS_RunAppEx.restype = ctypes.c_int64
    HCSYS_RunAppEx.argtypes = [ctypes.c_char_p, ctypes.c_char_p, ctypes.c_char_p, ctypes.c_int32, ctypes.c_long]
    
    ret = HCSYS_RunAppEx(
        auto_encode(路径),
        auto_encode(应用名),
        auto_encode(启动参数),
        ctypes.c_int32(标志),
        ctypes.c_long(返回值类型)
    )
    return ret

# INT64 __stdcall HCSYS_RunAppExxxx(char* path, char* appName, char* lparam, int flag, long type);
def HD系统_启动EXE带参数Ex(路径: str, 应用名: str, 启动参数: str, 标志: int, 返回值类型: int) -> int:
    """
    运行指定路径下的exe，支持启动参数，并指定了当前进程的路径
    
    Args:
        路径: exe路径
        应用名: exe名字
        启动参数: 启动参数
        标志: 启动标志（挂起状态打开(4), 直接打开运行(0)）
        返回值类型: 返回值类型（进程ID(0), 线程ID(1), 进程句柄(2), 线程句柄(3)）
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCSYS_RunAppExxxx = hd.HCSYS_RunAppExxxx
    HCSYS_RunAppExxxx.restype = ctypes.c_int64
    HCSYS_RunAppExxxx.argtypes = [ctypes.c_char_p, ctypes.c_char_p, ctypes.c_char_p, ctypes.c_int32, ctypes.c_long]
    
    ret = HCSYS_RunAppExxxx(
        auto_encode(路径),
        auto_encode(应用名),
        auto_encode(启动参数),
        ctypes.c_int32(标志),
        ctypes.c_long(返回值类型)
    )
    return ret

# INT64 __stdcall HCSYS_GetHDiskCode();
def HD系统_获取磁盘特征码() -> int:
    """
    获取磁盘特征码
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCSYS_GetHDiskCode = hd.HCSYS_GetHDiskCode
    HCSYS_GetHDiskCode.restype = ctypes.c_int64
    HCSYS_GetHDiskCode.argtypes = []
    
    ret = HCSYS_GetHDiskCode()
    return ret

# INT64 __stdcall HCSYS_GetCpuCode();
def HD系统_获取CPU特征码() -> int:
    """
    获取CPU特征码
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCSYS_GetCpuCode = hd.HCSYS_GetCpuCode
    HCSYS_GetCpuCode.restype = ctypes.c_int64
    HCSYS_GetCpuCode.argtypes = []
    
    ret = HCSYS_GetCpuCode()
    return ret

# INT64 __stdcall HCSYS_GetBIOSInfo();
def HD系统_获取BOIS制造日期() -> int:
    """
    获取BIOS制造日期
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCSYS_GetBIOSInfo = hd.HCSYS_GetBIOSInfo
    HCSYS_GetBIOSInfo.restype = ctypes.c_int64
    HCSYS_GetBIOSInfo.argtypes = []
    
    ret = HCSYS_GetBIOSInfo()
    return ret

# INT64 __stdcall HCSYS_GetMachineCode();
def HD系统_获取机器码() -> int:
    """
    获取机器码（包含网卡）
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCSYS_GetMachineCode = hd.HCSYS_GetMachineCode
    HCSYS_GetMachineCode.restype = ctypes.c_int64
    HCSYS_GetMachineCode.argtypes = []
    
    ret = HCSYS_GetMachineCode()
    return ret

# INT64 __stdcall HCSYS_GetMachineCodeNoMac();
def HD系统_获取机器码无网卡() -> int:
    """
    获取机器码（不包含网卡）
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCSYS_GetMachineCodeNoMac = hd.HCSYS_GetMachineCodeNoMac
    HCSYS_GetMachineCodeNoMac.restype = ctypes.c_int64
    HCSYS_GetMachineCodeNoMac.argtypes = []
    
    ret = HCSYS_GetMachineCodeNoMac()
    return ret

# INT64 __stdcall HCSYS_GetNetTime();
def HD系统_获取网络时间() -> int:
    """
    获取网络时间
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCSYS_GetNetTime = hd.HCSYS_GetNetTime
    HCSYS_GetNetTime.restype = ctypes.c_int64
    HCSYS_GetNetTime.argtypes = []
    
    ret = HCSYS_GetNetTime()
    return ret

# INT64 __stdcall HCSYS_GetNetTimeByIp(char* ip);
def HD系统_获取网络时间Ex(IP地址: str) -> int:
    """
    获取指定服务器IP的网络时间
    
    Args:
        IP地址: 服务器IP字符串（如: 127.0.0.1）
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCSYS_GetNetTimeByIp = hd.HCSYS_GetNetTimeByIp
    HCSYS_GetNetTimeByIp.restype = ctypes.c_int64
    HCSYS_GetNetTimeByIp.argtypes = [ctypes.c_char_p]
    
    ret = HCSYS_GetNetTimeByIp(auto_encode(IP地址))
    return ret

# INT64 __stdcall HCSYS_GetSystemBuildNumber();
def HD系统_获取系统版本() -> int:
    """
    获取系统版本
    
    Returns:
        int: 返回值代码（查看HD返回值表）
            大于0表示具体版本号
    """
    hd = Config.get_hd()
    
    HCSYS_GetSystemBuildNumber = hd.HCSYS_GetSystemBuildNumber
    HCSYS_GetSystemBuildNumber.restype = ctypes.c_int64
    HCSYS_GetSystemBuildNumber.argtypes = []
    
    ret = HCSYS_GetSystemBuildNumber()
    return ret

# INT64 __stdcall HCSYS_GetSystemType();
def HD系统_获取系统类型() -> int:
    """
    获取系统类型
    
    Returns:
        int: 返回值代码（查看HD返回值表）
            1: win95/98/me/nt4.0
            2: xp/2000
            3: 2003/2003 R2/xp-64
            4: win7/2008 R2
            5: vista/2008
            6: win8/2012
            7: win8.1/2012 R2
            8: win10/2016 TP/win11
            9: win11
    """
    hd = Config.get_hd()
    
    HCSYS_GetSystemType = hd.HCSYS_GetSystemType
    HCSYS_GetSystemType.restype = ctypes.c_int64
    HCSYS_GetSystemType.argtypes = []
    
    ret = HCSYS_GetSystemType()
    return ret

# INT64 __stdcall HCSYS_GetTime();
def HD系统_开机经过时间() -> int:
    """
    获取开机到现在过经过的时间（毫秒）
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCSYS_GetTime = hd.HCSYS_GetTime
    HCSYS_GetTime.restype = ctypes.c_int64
    HCSYS_GetTime.argtypes = []
    
    ret = HCSYS_GetTime()
    return ret

# INT64 __stdcall HCSYS_Is64Bit();
def HD系统_当前进程是否X64() -> int:
    """
    当前进程是否是64位
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCSYS_Is64Bit = hd.HCSYS_Is64Bit
    HCSYS_Is64Bit.restype = ctypes.c_int64
    HCSYS_Is64Bit.argtypes = []
    
    ret = HCSYS_Is64Bit()
    return ret

# INT64 __stdcall HCSYS_IsSurrpotVt();
def HD系统_是否支持vt() -> int:
    """
    是否支持VT
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCSYS_IsSurrpotVt = hd.HCSYS_IsSurrpotVt
    HCSYS_IsSurrpotVt.restype = ctypes.c_int64
    HCSYS_IsSurrpotVt.argtypes = []
    
    ret = HCSYS_IsSurrpotVt()
    return ret

# INT64 __stdcall HCSYS_GetScreenPixelDepth();
def HD系统_获取屏幕的色深() -> int:
    """
    获取屏幕的色深
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCSYS_GetScreenPixelDepth = hd.HCSYS_GetScreenPixelDepth
    HCSYS_GetScreenPixelDepth.restype = ctypes.c_int64
    HCSYS_GetScreenPixelDepth.argtypes = []
    
    ret = HCSYS_GetScreenPixelDepth()
    return ret

# INT64 __stdcall HCSYS_SetScreenPixelDepth(int dmBitsPerPel);
def HD系统_设置屏幕的色深(像素深度: int) -> int:
    """
    设置屏幕的色深
    
    Args:
        像素深度: 像素深度值（24/32等）
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCSYS_SetScreenPixelDepth = hd.HCSYS_SetScreenPixelDepth
    HCSYS_SetScreenPixelDepth.restype = ctypes.c_int64
    HCSYS_SetScreenPixelDepth.argtypes = [ctypes.c_int32]
    
    ret = HCSYS_SetScreenPixelDepth(ctypes.c_int32(像素深度))
    return ret

# INT64 __stdcall HCSYS_GetScreenHeight();
def HD系统_获取屏幕高度() -> int:
    """
    获取屏幕高度
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCSYS_GetScreenHeight = hd.HCSYS_GetScreenHeight
    HCSYS_GetScreenHeight.restype = ctypes.c_int64
    HCSYS_GetScreenHeight.argtypes = []
    
    ret = HCSYS_GetScreenHeight()
    return ret

# INT64 __stdcall HCSYS_GetScreenWidth();
def HD系统_获取屏幕宽度() -> int:
    """
    获取屏幕宽度
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCSYS_GetScreenWidth = hd.HCSYS_GetScreenWidth
    HCSYS_GetScreenWidth.restype = ctypes.c_int64
    HCSYS_GetScreenWidth.argtypes = []
    
    ret = HCSYS_GetScreenWidth()
    return ret

# INT64 __stdcall HCSYS_SetScreen(int width, int height);
def HD系统_设置屏幕分辨率(宽度: int, 高度: int) -> int:
    """
    设置屏幕分辨率
    
    Args:
        宽度: 屏幕宽度
        高度: 屏幕高度
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCSYS_SetScreen = hd.HCSYS_SetScreen
    HCSYS_SetScreen.restype = ctypes.c_int64
    HCSYS_SetScreen.argtypes = [ctypes.c_int32, ctypes.c_int32]
    
    ret = HCSYS_SetScreen(ctypes.c_int32(宽度), ctypes.c_int32(高度))
    return ret

# INT64 __stdcall HCSYS_GetCmdRet(char* cmd);
def HD系统_获取CMD命令返回值(命令: str) -> int:
    """
    获取CMD命令返回值（字符串）
    
    Args:
        命令: CMD命令
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCSYS_GetCmdRet = hd.HCSYS_GetCmdRet
    HCSYS_GetCmdRet.restype = ctypes.c_int64
    HCSYS_GetCmdRet.argtypes = [ctypes.c_char_p]
    
    ret = HCSYS_GetCmdRet(auto_encode(命令))
    return ret



from .config import *
from .HDDMA import *
from .HDHOOK import *
from .HDIP import *
from .HDLUA import *
from .HD主板机 import *
from .HD优化 import *
from .HD内存 import *
from .HD内置浏览器 import *
from .HD回调函数 import *
from .HD多线程 import *
from .HD截图 import *
from .HD扩展 import *
from .HD插件 import *
from .HD智能识图 import *
from .HD汇编 import *
from .HD注入 import *
from .HD状态机 import *
from .HD环境 import *
from .HD登录 import *
from .HD窗口 import *
from .HD系统 import *
from .HD识图 import *
from .HD识字 import *
from .HD调试 import *
from .HD资源 import *
from .HD返回值 import *
from .HD通用 import *
from .HD通讯 import *
from .HD键鼠 import *
from .HD驱动 import *
from .HD黑屏 import *
from .HD结构体 import *
from .HDVT import *
from .HDYOLOV import *
from .HD盾 import *
from .HDVNC import *
from .HDJSON import *
from .HD实时绘制 import *
from .HDPOCR import *